@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *  $Id: commands.c,v 1.24 2006/03/04 11:17:10 smorlat Exp $
+ *  $Id: commands.c,v 1.30 2006/09/08 15:32:57 smorlat Exp $
  *
  *  Copyright (C) 2006  Sandro Santilli <strk@keybit.net>
  *  Copyright (C) 2004  Simon MORLAT <simon.morlat@linphone.org>
@@ -53,7 +53,9 @@ static int lpc_cmd_refer(LinphoneCore *, char *);
 static int lpc_cmd_quit(LinphoneCore *, char *);
 static int lpc_cmd_nat(LinphoneCore *, char *);
 static int lpc_cmd_friend(LinphoneCore *, char*);
-
+static int lpc_cmd_soundcard(LinphoneCore *, char *);
+static int lpc_cmd_play(LinphoneCore *, char *);
+static int lpc_cmd_record(LinphoneCore *, char *);
 /* Command handler helpers */
 static void linphonec_proxy_add(LinphoneCore *lc);
 static void linphonec_proxy_display(LinphoneProxyConfig *lc);
@@ -95,6 +97,11 @@ LPC_COMMAND commands[] = {
 		"'proxy use <index>' : use proxy with number index as default proxy.\n"
 		"'proxy unuse' : don't use a default proxy."
 	},
+	{ "soundcard", lpc_cmd_soundcard, "Manage soundcards",
+		"'soundcard list' : list all sound devices.\n"
+		"'soundcard use <index>' : select a sound device.\n"
+		"'soundcard use files' : use .wav files instead of soundcard\n"
+	},
 	{ "ipv6", lpc_cmd_ipv6, "Use IPV6",
 		"'ipv6 status' : show ipv6 usage status.\n"
 		"'ipv6 enable' : enable the use of the ipv6 network.\n"
@@ -117,6 +124,14 @@ LPC_COMMAND commands[] = {
 		"'friend list [<pattern>]'    : list friends.\n"
 		"'friend call <index>         : call a friend."
 	},
+	{ "play", lpc_cmd_play, "play from a wav file",
+		"This feature is available only in file mode (see 'help soundcard')\n"
+		"'play <wav file>'    : play a wav file."
+	},
+	{ "record", lpc_cmd_record, "record to a wav file",
+		"This feature is available only in file mode (see 'help soundcard')\n"
+		"'record <wav file>'    : record into wav file."
+	},
 	{ "quit", lpc_cmd_quit, "Exit linphonec", NULL },
 	{ (char *)NULL, (lpc_cmd_handler)NULL, (char *)NULL, (char *)NULL }
 };
@@ -317,8 +332,8 @@ lpc_cmd_quit(LinphoneCore *lc, char *args)
 static int
 lpc_cmd_nat(LinphoneCore *lc, char *args)
 {
-	gboolean use;
-	const gchar *nat;
+	bool_t use;
+	const char *nat;
 
 	if ( args ) args=lpc_strip_blanks(args);
 
@@ -326,19 +341,21 @@ lpc_cmd_nat(LinphoneCore *lc, char *args)
 	{
 		if ( ! strncmp(args, "use", 3) )
 		{
-			linphone_core_set_nat_address(lc, NULL, TRUE);
+			linphone_core_use_nat_address(lc,TRUE);
 		}
 		else if ( ! strncmp(args, "unuse", 5) )
 		{
-			linphone_core_set_nat_address(lc, NULL, FALSE);
+			linphone_core_use_nat_address(lc,FALSE);
 		}
 		else
 		{
-			linphone_core_set_nat_address(lc, args, TRUE);
+			linphone_core_set_nat_address(lc, args);
+			linphone_core_use_nat_address(lc,TRUE);
 		}
 	}
 
-	nat = linphone_core_get_nat_address(lc, &use);
+	nat = linphone_core_get_nat_address(lc);
+	use = linphone_core_nat_address_used(lc);
 	printf("Nat address: %s%s\n", nat, use?"":" (unused)");
 
 	return 1;
@@ -374,6 +391,20 @@ lpc_cmd_friend(LinphoneCore *lc, char *args)
 	return 0;
 }
 
+static int lpc_cmd_play(LinphoneCore *lc, char *args){
+	if ( args ) args=lpc_strip_blanks(args);
+	if ( ! args || ! *args ) return 0;
+	linphone_core_set_play_file(lc,args);
+	return 1;
+}
+
+static int lpc_cmd_record(LinphoneCore *lc, char *args){
+	if ( args ) args=lpc_strip_blanks(args);
+	if ( ! args || ! *args ) return 0;
+	linphone_core_set_record_file(lc,args);
+	return 1;
+}
+
 /*
  * Modified input
  */
@@ -441,13 +472,13 @@ lpc_cmd_proxy(LinphoneCore *lc, char *args)
 static int
 lpc_cmd_call_logs(LinphoneCore *lc, char *args)
 {
-	GList *elem=linphone_core_get_call_logs(lc);
-	for (;elem!=NULL;elem=g_list_next(elem))
+	MSList *elem=linphone_core_get_call_logs(lc);
+	for (;elem!=NULL;elem=ms_list_next(elem))
 	{
 		LinphoneCallLog *cl=(LinphoneCallLog*)elem->data;
-		gchar *str=linphone_call_log_to_str(cl);
+		char *str=linphone_call_log_to_str(cl);
 		printf("%s\n",str);
-		g_free(str);
+		ms_free(str);
 	}
 	return 1;
 }
@@ -482,6 +513,49 @@ lpc_cmd_ipv6(LinphoneCore *lc, char *arg1)
 	return 1;
 }
 
+static int lpc_cmd_soundcard(LinphoneCore *lc, char *cmd){
+	int i;
+	if (cmd==NULL){
+		printf("Syntax error - see 'help soundcard'\n");
+		return 1;
+	}
+	if (strcmp(cmd,"list")==0){
+		const char **dev=linphone_core_get_sound_devices(lc);
+		for(i=0;dev[i]!=NULL;i++){
+			printf("%i: %s\n",i,dev[i]);
+		}
+		return 1;
+	}else{
+		char *tmp=alloca(strlen(cmd)+1);
+		char *card=alloca(strlen(cmd)+1);
+		int index;
+		int n=sscanf(cmd,"%s %s",tmp,card);
+		if (n==2 && strcmp(tmp,"use")==0){
+			if (strcmp(card,"files")==0) {
+				printf("Using wav files instead of soundcard.\n");
+				linphone_core_use_files(lc,TRUE);
+				return 1;
+			}else{
+				const char **dev=linphone_core_get_sound_devices(lc);
+				index=atoi(card);
+				for(i=0;dev[i]!=NULL;i++){
+					if (i==index){
+						linphone_core_set_ringer_device(lc,dev[i]);
+						linphone_core_set_playback_device(lc,dev[i]);
+						linphone_core_set_capture_device(lc,dev[i]);
+						printf("Using sound device %s\n",dev[i]);
+						return 1;
+					}
+				}
+				printf("no such sound device\n");
+				return 1;
+			}
+		}
+		printf("Syntax error - see 'help soundcard'\n");
+	}
+	return 1;
+}
+
 /***************************************************************************
  *
  *  Commands helper functions
@@ -492,7 +566,7 @@ lpc_cmd_ipv6(LinphoneCore *lc, char *arg1)
 static void
 linphonec_proxy_add(LinphoneCore *lc)
 {
-	gboolean enable_register=FALSE;
+	bool_t enable_register=FALSE;
 	LinphoneProxyConfig *cfg;
 
 	printf("Adding new proxy setup. Hit ^D to abort.\n");
@@ -619,7 +693,7 @@ linphonec_proxy_add(LinphoneCore *lc)
 			}
 
 			linphone_proxy_config_expires(cfg, expires);
-			printf("Expiration: %d microseconds\n", cfg->expires);
+			printf("Expiration: %d seconds\n", cfg->expires);
 
 			free(input);
 			break;
@@ -724,12 +798,12 @@ linphonec_proxy_display(LinphoneProxyConfig *cfg)
 static void
 linphonec_proxy_list(LinphoneCore *lc)
 {
-	GList *proxies;
+	MSList *proxies;
 	int n;
 	int def=linphone_core_get_default_proxy(lc,NULL);
 	
 	proxies=linphone_core_get_proxy_config_list(lc);
-	for(n=0;proxies!=NULL;proxies=g_list_next(proxies),n++){
+	for(n=0;proxies!=NULL;proxies=ms_list_next(proxies),n++){
 		if (n==def)
 			printf("****** Proxy %i - this is the default one - *******\n",n);
 		else 
@@ -741,10 +815,10 @@ linphonec_proxy_list(LinphoneCore *lc)
 static void
 linphonec_proxy_remove(LinphoneCore *lc, int index)
 {
-	GList *proxies;
+	MSList *proxies;
 	LinphoneProxyConfig *cfg;
 	proxies=linphone_core_get_proxy_config_list(lc);
-	cfg=(LinphoneProxyConfig*)g_list_nth_data(proxies,index);
+	cfg=(LinphoneProxyConfig*)ms_list_nth_data(proxies,index);
 	if (cfg==NULL){
 		printf("No such proxy.\n");
 		return;
@@ -757,10 +831,10 @@ linphonec_proxy_remove(LinphoneCore *lc, int index)
 static int
 linphonec_proxy_use(LinphoneCore *lc, int index)
 {
-	GList *proxies;
+	MSList *proxies;
 	LinphoneProxyConfig *cfg;
 	proxies=linphone_core_get_proxy_config_list(lc);
-	cfg=(LinphoneProxyConfig*)g_list_nth_data(proxies,index);
+	cfg=(LinphoneProxyConfig*)ms_list_nth_data(proxies,index);
 	if (cfg==NULL){
 		printf("No such proxy (try 'proxy list').");
 		return 0;
@@ -772,9 +846,9 @@ linphonec_proxy_use(LinphoneCore *lc, int index)
 static void
 linphonec_friend_display(LinphoneFriend *fr)
 {
-	gchar *name = linphone_friend_get_name(fr);
-	gchar *addr = linphone_friend_get_addr(fr);
-	//gchar *url = linphone_friend_get_url(fr);
+	char *name = linphone_friend_get_name(fr);
+	char *addr = linphone_friend_get_addr(fr);
+	//char *url = linphone_friend_get_url(fr);
 
 	printf("name: %s\n", name);
 	printf("address: %s\n", addr);
@@ -783,7 +857,7 @@ linphonec_friend_display(LinphoneFriend *fr)
 static int
 linphonec_friend_list(LinphoneCore *lc, char *pat)
 {
-	GList *friend;
+	MSList *friend;
 	int n;
 
 	if (pat) {
@@ -792,10 +866,10 @@ linphonec_friend_list(LinphoneCore *lc, char *pat)
 	}
 
 	friend = linphone_core_get_friend_list(lc);
-	for(n=0; friend!=NULL; friend=g_list_next(friend), ++n )
+	for(n=0; friend!=NULL; friend=ms_list_next(friend), ++n )
 	{
 		if ( pat ) {
-			gchar *name = linphone_friend_get_name(friend->data);
+			char *name = linphone_friend_get_name(friend->data);
 			if ( ! strstr(name, pat) ) continue;
 		}
 		printf("****** Friend %i *******\n",n);
@@ -808,11 +882,11 @@ linphonec_friend_list(LinphoneCore *lc, char *pat)
 static int
 linphonec_friend_call(LinphoneCore *lc, unsigned int num)
 {
-	GList *friend = linphone_core_get_friend_list(lc);
+	MSList *friend = linphone_core_get_friend_list(lc);
 	unsigned int n;
-	gchar *addr;
+	char *addr;
 
-	for(n=0; friend!=NULL; friend=g_list_next(friend), ++n )
+	for(n=0; friend!=NULL; friend=ms_list_next(friend), ++n )
 	{
 		if ( n == num )
 		{
@@ -858,6 +932,25 @@ lpc_find_command(const char *name)
 /****************************************************************************
  *
  * $Log: commands.c,v $
+ * Revision 1.30  2006/09/08 15:32:57  smorlat
+ * support for using files instead of soundcard (used by linphonec only)
+ *
+ * Revision 1.29  2006/08/28 14:29:07  smorlat
+ * fix bug.
+ *
+ * Revision 1.28  2006/08/21 12:49:59  smorlat
+ * merged several little patches.
+ *
+ * Revision 1.27  2006/07/17 18:45:00  smorlat
+ * support for several event queues in ortp.
+ * glib dependency removed from coreapi/ and console/
+ *
+ * Revision 1.26  2006/04/14 15:16:36  smorlat
+ * soundcard use did nothing !
+ *
+ * Revision 1.25  2006/04/06 20:09:33  smorlat
+ * add linphonec command to see and select sound devices.
+ *
  * Revision 1.24  2006/03/04 11:17:10  smorlat
  * mediastreamer2 in progress.
  *
