@@ -55,13 +55,13 @@ void sipomatic_process_event(Sipomatic *obj,eXosip_event_t *ev)
 		case EXOSIP_CALL_CANCELLED:
 			call=sipomatic_find_call(obj,ev->did);
 			if (call==NULL){
-				g_warning("Could not find call with did %i !",ev->did);
+				ms_warning("Could not find call with did %i !",ev->did);
 			}
 			call_release(call);
 			call_destroy(call);
 			break;
 		case EXOSIP_IN_SUBSCRIPTION_NEW:
-			g_message("Receving new incoming subscription.");
+			ms_message("Receving new incoming subscription.");
 			eXosip_notify_accept_subscribe(ev->did,200,EXOSIP_SUBCRSTATE_ACTIVE,EXOSIP_NOTIFY_ONLINE);
 			break;
 		default:
@@ -71,24 +71,25 @@ void sipomatic_process_event(Sipomatic *obj,eXosip_event_t *ev)
 }
 
 
-gint endoffile_cb(MSFilter *f,gint ev,gpointer arg,gpointer data)
-{
-	Call*call=(Call*)data;
+void endoffile_cb(void *ud, unsigned int ev,void * arg){
+	Call*call=(Call*)ud;
 	call->eof=1;
-	return 0;
 }
 
 void call_accept(Call *call)
 {
 	sdp_context_t *ctx;
 	PayloadType *payload;
-	gchar *hellofile;
-	
+	char *hellofile;
+	static int call_count=0;	
+	char record_file[250];
+	sprintf(record_file,"/tmp/sipomatic%i.wav",call_count);
+
 	ctx=call->sdpc;
 	payload=rtp_profile_get_payload(call->profile,call->audio.pt);
 	if (strcmp(payload->mime_type,"telephone-event")==0){
 		/* telephone-event is not enough to accept a call */
-		g_message("Cannot accept call with only telephone-event.\n");
+		ms_message("Cannot accept call with only telephone-event.\n");
 		eXosip_answer_call(call->did,415,NULL);
 		call->state=CALL_STATE_FINISHED;
 		return;
@@ -98,16 +99,17 @@ void call_accept(Call *call)
 	}else hellofile=call->root->file_path8000hz;
 	eXosip_answer_call_with_body(call->did,200,"application/sdp",call->sdpc->answerstr);
  	call->audio_stream=audio_stream_start_with_files(call->profile,call->audio.localport,
-				call->audio.remaddr,call->audio.remoteport,call->audio.pt,20,hellofile,"/dev/null");
+				call->audio.remaddr,call->audio.remoteport,call->audio.pt,20,hellofile,record_file);
+	call_count++;
 #ifdef VIDEO_ENABLED
 	if (call->video.remoteport!=0){
 		call->video_stream=video_stream_send_only_start(call->profile,call->video.localport,call->video.remaddr,
-											call->video.remoteport,call->video.pt,"Video4Linux","/dev/video0");
+											call->video.remoteport,call->video.pt,"/dev/video0");
 	}
 #endif
-	g_timer_reset(call->timer);
+	call->time=time(NULL);
 	call->state=CALL_STATE_RUNNING;
-	ms_filter_set_notify_func(call->audio_stream->soundread,endoffile_cb,(gpointer)call);
+	ms_filter_set_notify_callback(call->audio_stream->soundread,endoffile_cb,(void*)call);
 }
 
 
@@ -118,7 +120,7 @@ PayloadType * sipomatic_payload_is_supported(sdp_payload_t *payload,RtpProfile *
 		localpt=rtp_profile_get_payload_number_from_rtpmap(local_profile,payload->a_rtpmap);
 	}else{
 		localpt=payload->pt;
-		g_warning("payload has no rtpmap.");
+		ms_warning("payload has no rtpmap.");
 	}
 	
 	if (localpt>=0){
@@ -129,8 +131,8 @@ PayloadType * sipomatic_payload_is_supported(sdp_payload_t *payload,RtpProfile *
 		if (rtppayload==NULL) return NULL;
 		/*check if we have the appropriate coder/decoder for this payload */
 		if (strcmp(rtppayload->mime_type,"telephone-event")!=0) {
-			if (ms_audio_codec_info_get(rtppayload->mime_type)==NULL && ms_video_codec_info_get(rtppayload->mime_type)==NULL) {
-				g_message("Codec %s is not supported.", rtppayload->mime_type);
+			if (!ms_filter_codec_supported(rtppayload->mime_type)) {
+				ms_message("Codec %s is not supported.", rtppayload->mime_type);
 				return NULL;
 			}
 		}
@@ -160,7 +162,7 @@ int sipomatic_accept_audio_offer(sdp_context_t *ctx,sdp_payload_t *payload)
 	/* see if this codec is supported in our local rtp profile*/
 	supported=sipomatic_payload_is_supported(payload,&av_profile,call->profile);
 	if (supported==NULL) {
-		g_message("Refusing codec %i (%s)",payload->pt,payload->a_rtpmap);
+		ms_message("Refusing codec %i (%s)",payload->pt,payload->a_rtpmap);
 		return -1;
 	}
 	if (strcmp(supported->mime_type,"telephone-event")==0) return 0;
@@ -191,7 +193,7 @@ int sipomatic_accept_video_offer(sdp_context_t *ctx,sdp_payload_t *payload)
 	/* see if this codec is supported in our local rtp profile*/
 	supported=sipomatic_payload_is_supported(payload,&av_profile,call->profile);
 	if (supported==NULL) {
-		g_message("Refusing video codec %i (%s)",payload->pt,payload->a_rtpmap);
+		ms_message("Refusing video codec %i (%s)",payload->pt,payload->a_rtpmap);
 		return -1;
 	}
 	if (params->ncodecs==0 ){
@@ -213,7 +215,7 @@ int sipomatic_accept_video_offer(sdp_context_t *ctx,sdp_payload_t *payload)
 #endif
 }
 
-void sipomatic_init(Sipomatic *obj, gchar *url, gboolean ipv6)
+void sipomatic_init(Sipomatic *obj, char *url, bool_t ipv6)
 {
 	osip_uri_t *uri=NULL;
 	int port=5064;
@@ -232,16 +234,16 @@ void sipomatic_init(Sipomatic *obj, gchar *url, gboolean ipv6)
 		if (osip_uri_parse(uri,url)==0){
 			if (uri->port!=NULL) port=atoi(uri->port);
 		}else{
-			g_warning("Invalid identity uri:%s",url);
+			ms_warning("Invalid identity uri:%s",url);
 		}	
 	}
-	g_message("Starting using url %s",url);
-	obj->lock=g_mutex_new();
+	ms_message("Starting using url %s",url);
+	ms_mutex_init(&obj->lock,NULL);
 	obj->calls=NULL;
 	obj->acceptance_time=5;
 	obj->max_call_time=300;
-	obj->file_path8000hz=g_strdup_printf("%s/%s",PACKAGE_SOUND_DIR,ANNOUCE_FILE8000HZ);
-	obj->file_path16000hz=g_strdup_printf("%s/%s",PACKAGE_SOUND_DIR,ANNOUCE_FILE16000HZ);
+	obj->file_path8000hz=ms_strdup_printf("%s/%s",PACKAGE_SOUND_DIR,ANNOUCE_FILE8000HZ);
+	obj->file_path16000hz=ms_strdup_printf("%s/%s",PACKAGE_SOUND_DIR,ANNOUCE_FILE16000HZ);
 	osip_trace_initialize(OSIP_INFO1,stdout);
 	osip_trace_initialize(OSIP_INFO2,stdout);
 	osip_trace_initialize(OSIP_WARNING,stdout);
@@ -260,16 +262,16 @@ void sipomatic_init(Sipomatic *obj, gchar *url, gboolean ipv6)
 
 void sipomatic_uninit(Sipomatic *obj)
 {
-	g_mutex_free(obj->lock);
+	ms_mutex_destroy(&obj->lock);
 	eXosip_quit();
 }
 
 void sipomatic_iterate(Sipomatic *obj)
 {
-	GList *elem;
-	GList *to_be_destroyed=NULL;
+	MSList *elem;
+	MSList *to_be_destroyed=NULL;
 	Call *call;
-	gdouble time;
+	double elapsed;
 	eXosip_event_t *ev;
 
 	while((ev=eXosip_event_wait(0,0))!=NULL){
@@ -278,23 +280,23 @@ void sipomatic_iterate(Sipomatic *obj)
 	elem=obj->calls;
 	while(elem!=NULL){
 		call=(Call*)elem->data;
-		time=g_timer_elapsed(call->timer,NULL);
+		elapsed=time(NULL)-call->time;
 		switch(call->state){
 			case CALL_STATE_INIT:
-				if (time>obj->acceptance_time){
+				if (elapsed>obj->acceptance_time){
 					call_accept(call);
 				}
 			break;
 			case CALL_STATE_RUNNING:
-				if (time>obj->max_call_time || call->eof){
+				if (elapsed>obj->max_call_time || call->eof){
 					call_release(call);
-					to_be_destroyed=g_list_append(to_be_destroyed,call);
+					to_be_destroyed=ms_list_append(to_be_destroyed,call);
 				}
 			break;
 		}
-		elem=g_list_next(elem);
+		elem=ms_list_next(elem);
 	}
-	for(;to_be_destroyed!=NULL; to_be_destroyed=g_list_next(to_be_destroyed)){
+	for(;to_be_destroyed!=NULL; to_be_destroyed=ms_list_next(to_be_destroyed)){
 		call_destroy((Call*)to_be_destroyed->data);
 	}
 }
@@ -302,9 +304,9 @@ void sipomatic_iterate(Sipomatic *obj)
 
 Call* sipomatic_find_call(Sipomatic *obj,int did)
 {
-	GList *it;
+	MSList *it;
 	Call *call=NULL;
-	for (it=obj->calls;it!=NULL;it=g_list_next(it)){
+	for (it=obj->calls;it!=NULL;it=ms_list_next(it)){
 		call=(Call*)it->data;
 		if ( call->did==did) return call;
 	}
@@ -318,7 +320,7 @@ Call * call_new(Sipomatic *root, int did, char *sdp)
 	char *sdpans;
 	int status;
 	sdp_context_t *sdpc=sdp_handler_create_context(&sipomatic_sdp_handler,NULL,"sipomatic");
-	obj=g_new0(Call,1);
+	obj=ms_new0(Call,1);
 	obj->profile=rtp_profile_new("remote");
 	eXosip_answer_call(did,100,NULL);
 	sdp_context_set_user_pointer(sdpc,obj);
@@ -331,17 +333,17 @@ Call * call_new(Sipomatic *root, int did, char *sdp)
 		eXosip_answer_call(did,status,NULL);
 		sdp_context_free(sdpc);
 		rtp_profile_destroy(obj->profile);
-		g_free(obj);
+		ms_free(obj);
+		return NULL;
 	}
 	obj->sdpc=sdpc;
-	obj->timer=g_timer_new();
 	obj->did=did;
-	g_timer_start(obj->timer);
+	obj->time=time(NULL);
 	obj->audio_stream=NULL;
 	obj->state=CALL_STATE_INIT;
 	obj->eof=0;
 	obj->root=root;
-	root->calls=g_list_append(root->calls,obj);
+	root->calls=ms_list_append(root->calls,obj);
 	return obj;
 }
 
@@ -357,19 +359,18 @@ void call_release(Call *call)
 
 void call_destroy(Call *obj)
 {
-	obj->root->calls=g_list_remove(obj->root->calls,(gpointer)obj);
+	obj->root->calls=ms_list_remove(obj->root->calls,obj);
 	rtp_profile_destroy(obj->profile);
-	g_timer_destroy(obj->timer);
 	sdp_context_free(obj->sdpc);
-	g_free(obj);
+	ms_free(obj);
 }
 
 void sipomatic_set_annouce_file(Sipomatic *obj, char *file)
 {
 	if (obj->file_path8000hz!=NULL){
-		g_free(obj->file_path8000hz);
+		ms_free(obj->file_path8000hz);
 	}
-	obj->file_path8000hz=g_strdup(file);
+	obj->file_path8000hz=ms_strdup(file);
 }
 
 
@@ -397,8 +398,8 @@ int main(int argc, char *argv[])
 {
 	int sendport=5070;
 	char *file=NULL;
-	gchar *url=NULL;
-	gboolean ipv6=FALSE;
+	char *url=NULL;
+	bool_t ipv6=FALSE;
 	int i;
 	
 	for(i=1;i<argc;i++){
@@ -434,15 +435,15 @@ int main(int argc, char *argv[])
 	}
 	
 	signal(SIGINT,stop_handler);
-	ms_init();
-	ms_speex_codec_init();
 	ortp_init();
+	ms_init();
+	ortp_set_log_level_mask(ORTP_MESSAGE|ORTP_WARNING|ORTP_ERROR|ORTP_FATAL);
 	rtp_profile_set_payload(&av_profile,115,&payload_type_lpc1015);
 	rtp_profile_set_payload(&av_profile,110,&payload_type_speex_nb);
 	rtp_profile_set_payload(&av_profile,111,&payload_type_speex_wb);
 	rtp_profile_set_payload(&av_profile,112,&payload_type_ilbc);
 	rtp_profile_set_payload(&av_profile,101,&payload_type_telephone_event);
-    rtp_profile_set_payload(&av_profile,116,&payload_type_truespeech);
+	rtp_profile_set_payload(&av_profile,116,&payload_type_truespeech);
 	rtp_profile_set_payload(&av_profile,98,&payload_type_h263_1998);
 	
 	sipomatic_init(&sipomatic,url,ipv6);
