@@ -20,8 +20,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "exevents.h"
 #include "linphonecore.h"
 #include "private.h"
-#include "misc.h"
-#include <mediastream.h>
+#include "mediastreamer2/mediastream.h"
 #include <eXosip.h>
 #include <osipparser2/osip_message.h>
 
@@ -34,13 +33,6 @@ extern LinphoneProxyConfig *linphone_core_get_proxy_config_from_rid(LinphoneCore
 void linphone_subscription_answered(LinphoneCore *lc,char *from, int sid);
 void linphone_subscription_closed(LinphoneCore *lc,char *from, int did);
 
-/* these are useful messages for the status */
-extern gchar *ready;
-extern gchar *end;
-extern gchar *contacting;
-extern gchar *connected;
-extern gchar *cancel;
-extern gchar *contacted;
 
 
 
@@ -49,13 +41,13 @@ int linphone_call_accepted(LinphoneCore *lc,int id, const char *sdpbody)
 	StreamParams *audio_params;
 	LinphoneCall *call=lc->call;
 	if (call==NULL){
-		g_warning("No call to accept.");
+		ms_warning("No call to accept.");
 		return 0;
 	}
 	audio_params=&call->audio_params;
 	call->auth_pending=FALSE;
 	if (strlen(sdpbody)==0) {
-		g_warning("No sdp body in 200ok.");
+		ms_warning("No sdp body in 200ok.");
 		return 0;
 	}
 	if (call->state==LCStateAVRunning){
@@ -63,7 +55,7 @@ int linphone_call_accepted(LinphoneCore *lc,int id, const char *sdpbody)
 	}
 	sdp_context_read_answer(lc->call->sdpctx,sdpbody);
 	lc->vtable.show(lc);
-	lc->vtable.display_status(lc,connected);
+	lc->vtable.display_status(lc,_("Connected."));
 	lc->call->state=LCStateAVRunning;
 	if (lc->ringstream!=NULL){
 		ring_stop(lc->ringstream);
@@ -81,19 +73,19 @@ int linphone_call_terminated(LinphoneCore *lc, eXosip_event_t *ev)
 	if (lc->call!=NULL){
 		if (lc->call->cid!=ev->cid){
 			/* this is not current call */
-			g_message("call %i terminated, this was not current call.",ev->cid);
+			ms_message("call %i terminated, this was not current call.",ev->cid);
 			return 0;
 		}
 	}
 	
-	g_message("Current call terminated...");
+	ms_message("Current call terminated...");
 	if (lc->ringstream!=NULL) {
 		ring_stop(lc->ringstream);
 		lc->ringstream=NULL;
 	}
 	linphone_core_stop_media_streams(lc);
 	lc->vtable.show(lc);
-	lc->vtable.display_status(lc,end);
+	lc->vtable.display_status(lc,_("Call terminated."));
 	if (lc->vtable.bye_recv!=NULL)
 		lc->vtable.bye_recv(lc,ev->remote_uri);
 	if (lc->call!=NULL){
@@ -155,7 +147,7 @@ int linphone_call_failure(LinphoneCore *lc,int cid, int code)
 				umsg=g_malloc(strlen(tmpmsg)+strlen(retrymsg)+13);
 				sprintf(umsg,retrymsg,tmpmsg,atoi(retry->hvalue)/60);
 				lc->vtable.display_message(lc,umsg);
-				g_free(umsg);
+				ms_free(umsg);
 			}*/		
 			lc->vtable.display_message(lc,tmpmsg);
 		break;
@@ -181,12 +173,11 @@ int linphone_call_failure(LinphoneCore *lc,int cid, int code)
 				reason=osip_message_get_reason(code);
 				lc->vtable.display_status(lc,(char*)reason);
 			}
-			else g_warning("failure_cb unknown code=%i\n",code);	
+			else ms_warning("failure_cb unknown code=%i\n",code);	
 	}
 	if (lc->ringstream!=NULL) {
 		ring_stop(lc->ringstream);
 		lc->ringstream=NULL;
-		restore_sound_daemons();
 	}
 	linphone_core_stop_media_streams(lc);
 	if (lc->call!=NULL) linphone_call_destroy(lc->call);
@@ -215,7 +206,7 @@ int linphone_inc_new_call(LinphoneCore *lc, eXosip_event_t *ev)
 	
 	/* first check if we can answer successfully to this invite */
 	if (lc->presence_mode!=LINPHONE_STATUS_ONLINE){
-		g_message("Not present !! presence mode : %d\n",lc->presence_mode);
+		ms_message("Not present !! presence mode : %d\n",lc->presence_mode);
 		eXosip_lock();
 		if (lc->presence_mode==LINPHONE_STATUS_BUSY)
 		  
@@ -258,7 +249,7 @@ int linphone_inc_new_call(LinphoneCore *lc, eXosip_event_t *ev)
 		goto end;
 	}
 	if (strlen(sdp_body)==0){
-		g_warning("No sdp body !");
+		ms_warning("No sdp body !");
 		eXosip_lock();
 		eXosip_answer_call(did,603,NULL);
 		eXosip_unlock();
@@ -309,39 +300,35 @@ int linphone_inc_new_call(LinphoneCore *lc, eXosip_event_t *ev)
 				eXosip_answer_call(did,180,NULL);
 				eXosip_unlock();
 				/* play the ring */
-				if (try_open_dsp(lc)>0){
-					g_message("Starting local ring...");
-					lc->ringstream=ring_start(lc->sound_conf.local_ring,
-							2,snd_card_manager_get_card(snd_card_manager,lc->sound_conf.ring_sndcard));
-				}
+				lc->ringstream=ring_start(lc->sound_conf.local_ring,
+							2000,lc->sound_conf.ring_sndcard);
 			}
 #else
 			eXosip_lock();
 			eXosip_answer_call(did,180,NULL);
 			eXosip_unlock();
 			/* play the ring */
-			if (try_open_dsp(lc)>0){
-				g_message("Starting local ring...");
-				lc->ringstream=ring_start(lc->sound_conf.local_ring,
-						2,snd_card_manager_get_card(snd_card_manager,lc->sound_conf.ring_sndcard));
-			}else g_warning("Could not start local ring !");
+			if (lc->sound_conf.ring_sndcard!=NULL){
+				ms_message("Starting local ring...");
+				lc->ringstream=ring_start(lc->sound_conf.local_ring,2000,lc->sound_conf.ring_sndcard);
+			}
 #endif
 			linphone_call_set_state(lc->call,LCStateRinging);
 			{
 				char *tmp;
 				if (from_2char_without_params(from_url,&tmp)==0){
-					barmesg=g_strdup_printf("%s %s",tmp,contacted);
+					barmesg=ortp_strdup_printf("%s %s",tmp,_("is contacting you."));
 					lc->vtable.show(lc);
 					lc->vtable.display_status(lc,barmesg);
 					lc->vtable.inv_recv(lc,tmp);
-					g_free(barmesg);
+					ms_free(barmesg);
 					osip_free(tmp);
 				}
 			}
 		break;
 		default:	
 			if (status==-1) status=415;
-			g_warning("Error during sdp negociation. status : %d\n",status);
+			ms_warning("Error during sdp negociation. status : %d\n",status);
 			eXosip_lock();
 			eXosip_answer_call(did,status,NULL);
 			eXosip_unlock();
@@ -354,9 +341,9 @@ int linphone_inc_new_call(LinphoneCore *lc, eXosip_event_t *ev)
 }
 
 void linphone_do_automatic_redirect(LinphoneCore *lc, const char *contact){
-	char *msg=g_strdup_printf(_("Redirected to %s..."),contact);
+	char *msg=ortp_strdup_printf(_("Redirected to %s..."),contact);
 	lc->vtable.display_status(lc,msg);
-	g_free(msg);
+	ms_free(msg);
 	if (lc->call!=NULL) linphone_call_destroy(lc->call);
 	lc->call=NULL;
 	linphone_core_invite(lc,contact);
@@ -375,6 +362,15 @@ void linphone_call_redirected(LinphoneCore *lc, int cid,int code, const char *co
 	}
 }
 
+static int get_audio_max_bw(const LinphoneCore *lc){
+	int dbw=linphone_core_get_download_bandwidth(lc);
+	int ubw=linphone_core_get_upload_bandwidth(lc);
+	if (dbw==0)
+		dbw=1<<30;
+	if (ubw==0)
+		ubw=1<<30;
+	return MIN(MIN(dbw,ubw),64);
+}
 
 /* these are the SdpHandler callbacks: we are called in to be aware of the content
 of the SDP messages exchanged */
@@ -384,43 +380,33 @@ int linphone_set_audio_offer(sdp_context_t *ctx)
 	LinphoneCall *call=(LinphoneCall*)sdp_context_get_user_pointer(ctx);
 	LinphoneCore *lc=call->core;
 	PayloadType *codec;
-	GList *elem;
+	MSList *elem;
 	sdp_payload_t payload;
 	
 	
-	/* set the nat address in the SDP, if given */
-	if (lc->net_conf.nat_address!=NULL && lc->net_conf.use_nat){
-		sdp_message_t *sdp=ctx->offer;
-		osip_free(sdp->c_connection->c_addr);
-		sdp->c_connection->c_addr=osip_strdup(lc->net_conf.nat_address);
-	}
-	
-	
 	elem=lc->codecs_conf.audio_codecs;
 	while(elem!=NULL){
 		codec=(PayloadType*) elem->data;
-		if (payload_type_usable(codec) && payload_type_enabled(codec)){
+		if (linphone_core_check_payload_type_usability(lc,codec) && payload_type_enabled(codec)){
 			sdp_payload_init(&payload);
-			payload.a_rtpmap=g_strdup_printf("%s/%i/1",codec->mime_type,codec->clock_rate);
+			payload.a_rtpmap=ortp_strdup_printf("%s/%i/1",codec->mime_type,codec->clock_rate);
 			payload.pt=rtp_profile_get_payload_number_from_rtpmap(lc->local_profile,payload.a_rtpmap);
 			payload.localport=lc->rtp_conf.audio_rtp_port;
-			/* when setting speex, add a b=<AS>: to choose bitrate */
-			if (strcasecmp(codec->mime_type,"speex")==0){
-				payload.b_as_bandwidth=codec->normal_bitrate/1000;
-			}else if (strcasecmp(codec->mime_type,"iLBC")==0){
+			if (strcasecmp(codec->mime_type,"iLBC")==0){
 				/* prefer the 30 ms mode */
 				payload.a_fmtp="ptime=30";
 			}
 			sdp_context_add_audio_payload(ctx,&payload);
-			g_free(payload.a_rtpmap);
+			ms_free(payload.a_rtpmap);
 		}
-		elem=g_list_next(elem);
+		elem=ms_list_next(elem);
 	}
 	/* add telephone-event payload*/
 	sdp_payload_init(&payload);
 	payload.pt=rtp_profile_get_payload_number_from_mime(lc->local_profile,"telephone-event");
 	payload.a_rtpmap="telephone-event/8000";
 	payload.a_fmtp="0-11";
+	payload.b_as_bandwidth=get_audio_max_bw(lc);
 	sdp_context_add_audio_payload(ctx,&payload);
 	return 0;
 }
@@ -431,19 +417,27 @@ int linphone_set_video_offer(sdp_context_t *ctx)
 	LinphoneCall *call=(LinphoneCall*)sdp_context_get_user_pointer(ctx);
 	LinphoneCore *lc=call->core;
 	PayloadType *codec;
-	GList *elem;
-	
-	for(elem=lc->codecs_conf.video_codecs;elem!=NULL;elem=g_list_next(elem)){
+	MSList *elem;
+	bool_t firsttime=TRUE;	
+
+	if (!linphone_core_video_enabled(lc)) return -1;
+
+	for(elem=lc->codecs_conf.video_codecs;elem!=NULL;elem=ms_list_next(elem)){
 		codec=(PayloadType*) elem->data;
-		if (payload_type_usable(codec) && payload_type_enabled(codec)){
+		if (linphone_core_check_payload_type_usability(lc,codec) && payload_type_enabled(codec)){
 			sdp_payload_t payload;
 			sdp_payload_init(&payload);
 			payload.line=1;
-			payload.a_rtpmap=g_strdup_printf("%s/%i",codec->mime_type,codec->clock_rate);
+			payload.a_rtpmap=ortp_strdup_printf("%s/%i",codec->mime_type,codec->clock_rate);
 			payload.localport=lc->rtp_conf.video_rtp_port;
 			payload.pt=rtp_profile_get_payload_number_from_rtpmap(lc->local_profile,payload.a_rtpmap);
+			payload.a_fmtp=codec->recv_fmtp;
+			if(firsttime){
+				firsttime=FALSE;
+				payload.b_as_bandwidth=codec->normal_bitrate/1000;
+			}
 			sdp_context_add_video_payload(ctx,&payload);
-			g_free(payload.a_rtpmap);
+			ms_free(payload.a_rtpmap);
 		}
 	}
 	return 0;
@@ -455,7 +449,7 @@ typedef enum {
 	SupportedAndValid  /* valid= the presence of this codec is enough to make a call */
 }SupportLevel;
 
-SupportLevel linphone_payload_is_supported(sdp_payload_t *payload,RtpProfile *local_profile,RtpProfile *dialog_profile)
+SupportLevel linphone_payload_is_supported(LinphoneCore *lc, sdp_payload_t *payload,RtpProfile *local_profile,RtpProfile *dialog_profile)
 {
 	int localpt;
 	SupportLevel ret;
@@ -463,7 +457,7 @@ SupportLevel linphone_payload_is_supported(sdp_payload_t *payload,RtpProfile *lo
 		localpt=rtp_profile_get_payload_number_from_rtpmap(local_profile,payload->a_rtpmap);
 	}else{
 		localpt=payload->pt;
-		g_warning("payload has no rtpmap.");
+		ms_warning("payload has no rtpmap.");
 	}
 	
 	if (localpt>=0 && localpt <128 ){
@@ -471,38 +465,39 @@ SupportLevel linphone_payload_is_supported(sdp_payload_t *payload,RtpProfile *lo
 		PayloadType *rtppayload;
 		rtppayload=rtp_profile_get_payload(local_profile,localpt);
 		if (rtppayload==NULL) {
-			g_warning("strange error !!");
+			ms_warning("strange error !!");
 			return Unsupported;
 		}
 		if (strcmp(rtppayload->mime_type,"telephone-event")!=0){
-			if (!payload_type_usable(rtppayload) ){
-				g_warning("payload %s is not usable",rtppayload->mime_type);
+			if (!linphone_core_check_payload_type_usability(lc,rtppayload) ){
+				ms_warning("payload %s is not usable",rtppayload->mime_type);
 				return Unsupported;
 			}
 			if ( !payload_type_enabled(rtppayload)) {
-				g_warning("payload %s is not enabled.",rtppayload->mime_type);
+				ms_warning("payload %s is not enabled.",rtppayload->mime_type);
 				return Unsupported;
 			}
 			ret=SupportedAndValid;
 		}else ret=Supported;
 		if (dialog_profile!=NULL){
+			int bw;
 			/* this payload is supported in our local rtp profile, so add it to the dialog rtp
 			profile */
 			rtppayload=payload_type_clone(rtppayload);
 			rtp_profile_set_payload(dialog_profile,payload->pt,rtppayload);
 			/* add to the rtp payload type some other parameters (bandwidth) */
-			if (payload->b_as_bandwidth!=0)
-				rtppayload->normal_bitrate=payload->b_as_bandwidth*1000;
+			if (rtppayload->type==PAYLOAD_VIDEO)
+				bw=rtppayload->normal_bitrate/1000;
+			else 
+				bw=get_audio_max_bw(lc);
+			if (payload->b_as_bandwidth!=0){
+				rtppayload->normal_bitrate=MIN(payload->b_as_bandwidth*1000,rtppayload->normal_bitrate);
+			}
+			payload->b_as_bandwidth=bw;
 			if (payload->a_fmtp!=NULL){
 				payload_type_set_send_fmtp(rtppayload,payload->a_fmtp);
 			}
-			if (strcasecmp(rtppayload->mime_type,"iLBC")==0){
-				/*default to 30 ms mode */
-				if (payload->a_fmtp==NULL){
-					payload->a_fmtp="ptime=30";
-					payload_type_set_recv_fmtp(rtppayload,payload->a_fmtp);
-				}
-			}
+			payload->a_fmtp=rtppayload->recv_fmtp;
 		}
 		return ret;
 	}
@@ -523,9 +518,9 @@ int linphone_accept_audio_offer(sdp_context_t *ctx,sdp_payload_t *payload)
 	}
 	remote_profile=call->profile;
 	/* see if this codec is supported in our local rtp profile*/
-	supported=linphone_payload_is_supported(payload,lc->local_profile,remote_profile);
+	supported=linphone_payload_is_supported(lc,payload,lc->local_profile,remote_profile);
 	if (supported==Unsupported) {
-		g_message("Refusing audio codec %i (%s)",payload->pt,payload->a_rtpmap);
+		ms_message("Refusing audio codec %i (%s)",payload->pt,payload->a_rtpmap);
 		return -1;
 	}
 	if (supported==SupportedAndValid) {
@@ -553,15 +548,18 @@ int linphone_accept_video_offer(sdp_context_t *ctx,sdp_payload_t *payload)
 	RtpProfile *remote_profile;
 	StreamParams *params;
 	SupportLevel supported;
+
+	if (!linphone_core_video_enabled(lc)) return -1;
+
 	if (call->profile==NULL){
 		/* create a remote user agent profile */
-		call->profile=remote_profile=rtp_profile_new("remote");
+		call->profile=rtp_profile_new("remote");
 	}
 	remote_profile=call->profile;
 	/* see if this codec is supported in our local rtp profile*/
-	supported=linphone_payload_is_supported(payload,lc->local_profile,remote_profile);
+	supported=linphone_payload_is_supported(lc,payload,lc->local_profile,remote_profile);
 	if (supported==Unsupported) {
-		g_message("Refusing video codec %i (%s)",payload->pt,payload->a_rtpmap);
+		ms_message("Refusing video codec %i (%s)",payload->pt,payload->a_rtpmap);
 		return -1;
 	}
 	if (supported==SupportedAndValid){
@@ -575,7 +573,7 @@ int linphone_accept_video_offer(sdp_context_t *ctx,sdp_payload_t *payload)
 			params->remoteaddr=payload->c_addr;
 			params->initialized=1;
 		}else{
-			/* refuse all other audio lines*/
+			/* refuse all other video lines*/
 			if(params->line!=payload->line) return -1;
 		}
 	}
@@ -590,9 +588,9 @@ int linphone_read_audio_answer(sdp_context_t *ctx,sdp_payload_t *payload)
 	SupportLevel supported;
 	
 	/* paranoid check: see if this codec is supported in our local rtp profile*/
-	supported=linphone_payload_is_supported(payload,lc->local_profile,call->profile);
+	supported=linphone_payload_is_supported(lc, payload,lc->local_profile,call->profile);
 	if (supported==Unsupported) {
-		g_warning("This remote sip phone did not answer properly to my sdp offer!");
+		ms_warning("This remote sip phone did not answer properly to my sdp offer!");
 		return 0;
 	}
 	if (supported==SupportedAndValid){
@@ -618,9 +616,9 @@ int linphone_read_video_answer(sdp_context_t *ctx,sdp_payload_t *payload)
 	SupportLevel supported;
 	
 	/* paranoid check: see if this codec is supported in our local rtp profile*/
-	supported=linphone_payload_is_supported(payload,lc->local_profile,call->profile);
+	supported=linphone_payload_is_supported(lc, payload,lc->local_profile,call->profile);
 	if (supported==Unsupported) {
-		g_warning("This remote sip phone did not answer properly to my sdp offer!");
+		ms_warning("This remote sip phone did not answer properly to my sdp offer!");
 		return 0;
 	}
 	if (supported==SupportedAndValid){
@@ -640,7 +638,7 @@ int linphone_read_video_answer(sdp_context_t *ctx,sdp_payload_t *payload)
 
 void linphone_call_proceeding(LinphoneCore *lc, int cid, int did){
 	if (lc->call==NULL){
-		g_warning("Bug in call_proceeding()");
+		ms_warning("Bug in call_proceeding()");
 		return;
 	}
 	lc->call->cid=cid;
@@ -655,10 +653,10 @@ void linphone_call_ringing(LinphoneCore *lc, eXosip_event_t *ev){
 	
 	if (ev->status_code==180){
 		if (lc->ringstream!=NULL) return;	/*already ringing !*/
-		g_message("Remote ringing...");
-		if (try_open_dsp(lc)>0)
-			lc->ringstream=ring_start(lc->sound_conf.remote_ring,2,snd_card_manager_get_card(snd_card_manager,lc->sound_conf.play_sndcard));
-		else g_warning("Could not start remote ring !");
+		if (lc->sound_conf.play_sndcard!=NULL){
+			ms_message("Remote ringing...");
+			lc->ringstream=ring_start(lc->sound_conf.remote_ring,2000,lc->sound_conf.play_sndcard);
+		}
 	}else if (strlen(ev->sdp_body)>0){
 		/* somebody reported a server who uses a 183 answer to establish mediastreams and play
 		an informationnal message */
@@ -677,21 +675,21 @@ void linphone_registration_faillure(LinphoneCore *lc,eXosip_event_t *ev)
 			linphone_register_authentication_required(lc,ev);
 			break;
 		default:
-			if (strlen(ev->reason_phrase)==0) msg=g_strdup_printf(_("Registration on %s failed (timeout)."),ev->req_uri);
+			if (strlen(ev->reason_phrase)==0) msg=ortp_strdup_printf(_("Registration on %s failed (timeout)."),ev->req_uri);
 			else msg=ev->reason_phrase;
 			lc->vtable.display_status(lc,msg);
-			if ( msg != ev->reason_phrase ) g_free(msg);
+			if ( msg != ev->reason_phrase ) ms_free(msg);
 	}
 	
 }
 
 void linphone_registration_success(LinphoneCore *lc,eXosip_event_t *ev){
 	LinphoneProxyConfig *cfg;
-	gchar *msg=g_strdup_printf(_("Registration on %s sucessful."),ev->req_uri);
+	char *msg=ms_strdup_printf(_("Registration on %s sucessful."),ev->req_uri);
 	lc->vtable.display_status(lc,msg);
-	g_free(msg);
+	ms_free(msg);
 	cfg=linphone_core_get_proxy_config_from_rid(lc,ev->rid);
-	g_return_if_fail(cfg!=NULL);
+	ms_return_if_fail(cfg!=NULL);
 	cfg->auth_pending=FALSE;
 	cfg->registered=TRUE;
 }
@@ -700,55 +698,55 @@ void linphone_core_process_event(LinphoneCore *lc,eXosip_event_t *ev)
 {
 	switch(ev->type){
 		case EXOSIP_CALL_ANSWERED:
-			g_message("CALL_ANSWERED\n");
+			ms_message("CALL_ANSWERED\n");
 			linphone_call_accepted(lc,ev->did,ev->sdp_body);
 			/*send the ack once streams are started*/
 			eXosip_send_ack(ev->did);
 			break;
 		case EXOSIP_CALL_CLOSED:
 		case EXOSIP_CALL_CANCELLED:
-			g_message("CALL_CLOSED or CANCELLED\n");
+			ms_message("CALL_CLOSED or CANCELLED\n");
 			linphone_call_terminated(lc,ev);
 			break;
 		case EXOSIP_CALL_TIMEOUT:
 		case EXOSIP_CALL_NOANSWER:
-			g_message("CALL_TIMEOUT or NOANSWER\n");
+			ms_message("CALL_TIMEOUT or NOANSWER\n");
 			linphone_call_failure(lc,ev->did,-110);
 			break;
 		case EXOSIP_CALL_REQUESTFAILURE:
 		case EXOSIP_CALL_GLOBALFAILURE:
 		case EXOSIP_CALL_SERVERFAILURE:
-			g_message("CALL_REQUESTFAILURE or GLOBALFAILURE or SERVERFAILURE\n");
+			ms_message("CALL_REQUESTFAILURE or GLOBALFAILURE or SERVERFAILURE\n");
 			linphone_call_failure(lc,ev->did,ev->status_code);
 			break;
 		case EXOSIP_CALL_NEW:
-			g_message("CALL_NEW\n");
+			ms_message("CALL_NEW\n");
 			/* CALL_NEW is used twice in qos mode : 
 			 * when you receive invite (textinfo = "With QoS" or "Without QoS")
 			 * and when you receive update (textinfo = "New Call") */
 			linphone_inc_new_call(lc,ev);
 			break;
 		case EXOSIP_CALL_ACK:
-			g_message("CALL_ACK\n");
+			ms_message("CALL_ACK\n");
 			break;
 		case EXOSIP_CALL_REDIRECTED:
-			g_message("CALL_REDIRECTED\n");
+			ms_message("CALL_REDIRECTED\n");
 			linphone_call_redirected(lc,ev->did,ev->status_code,ev->remote_contact);
 			break;
 		case EXOSIP_CALL_PROCEEDING:
-			g_message("CALL_PROCEEDING\n");
+			ms_message("CALL_PROCEEDING\n");
 			linphone_call_proceeding(lc,ev->cid,ev->did);
 			break;
 		case EXOSIP_CALL_RINGING:
-			g_message("CALL_RINGING\n");
+			ms_message("CALL_RINGING\n");
 			linphone_call_ringing(lc,ev);
 			break;
 		case EXOSIP_IN_SUBSCRIPTION_NEW:
-			g_message("CALL_SUBSCRIPTION_NEW or UPDATE\n");
+			ms_message("CALL_SUBSCRIPTION_NEW or UPDATE\n");
 			linphone_subscription_new(lc,ev->did,ev->nid,ev->remote_uri,ev->remote_contact);
 			break;
 		case EXOSIP_SUBSCRIPTION_NOTIFY:
-			g_message("CALL_SUBSCRIPTION_NOTIFY\n");
+			ms_message("CALL_SUBSCRIPTION_NOTIFY\n");
 			linphone_notify_recv(lc,ev->remote_uri,ev->online_status);
 			break;
 		case EXOSIP_SUBSCRIPTION_ANSWERED:
@@ -759,17 +757,17 @@ void linphone_core_process_event(LinphoneCore *lc,eXosip_event_t *ev)
 			break;
 		case EXOSIP_CALL_HOLD:
 		case EXOSIP_CALL_OFFHOLD:
-			g_message("CALL_HOLD ou OFFHOLD\n");
+			ms_message("CALL_HOLD ou OFFHOLD\n");
 			break;
 		case EXOSIP_CALL_STARTAUDIO:
-			g_message("CALL_STARTAUDIO\n");
+			ms_message("CALL_STARTAUDIO\n");
 			break;
 		case EXOSIP_CALL_RELEASED:
-			g_message("CALL_RELEASED\n");
+			ms_message("CALL_RELEASED\n");
 			linphone_call_released(lc, ev->cid);
 			break;
 		case EXOSIP_REGISTRATION_FAILURE:
-			g_message("REGISTRATION_FAILURE\n");
+			ms_message("REGISTRATION_FAILURE\n");
 			linphone_registration_faillure(lc,ev);
 			break;
 		case EXOSIP_REGISTRATION_SUCCESS:
