@@ -1,6 +1,6 @@
 /*
 linphone
-Copyright (C) 2000  Simon MORLAT (simon.morlat@free.fr)
+Copyright (C) 2000  Simon MORLAT (simon.morlat@linphone.org)
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -19,112 +19,73 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #ifndef LINPHONECORE_H
 #define LINPHONECORE_H
 
-#include <sndcard.h>
-
-#undef PACKAGE
-#undef VERSION
-
-#include <config.h>
-
-#ifdef HAVE_GETTEXT
-#include <libintl.h>
-#ifndef _
-#define _(String) gettext(String)
-#endif
-#else
-#define _(something)	(something)
-#endif
-
-#ifdef HAVE_GLIB
-#include <glib.h>
-#else
-#include <uglib.h>
-#endif
 
 #include <osipparser2/osip_message.h>
-
+#include <ortp/ortp.h>
+#include <ortp/payloadtype.h>
+#include <mediastreamer2/mscommon.h>
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-#ifndef PayloadType_defined
-#define PayloadType_defined
-typedef struct _PayloadType PayloadType;
-#endif
+struct _MSSndCard;
+struct _LinphoneCore;
 
-gboolean payload_type_enabled(struct _PayloadType *pt);
-gboolean payload_type_usable(struct _PayloadType *pt);
-void payload_type_set_enable(struct _PayloadType *pt,gint value);
-void payload_type_set_usable(struct _PayloadType *pt,gint value);
-gchar *payload_type_get_description(struct _PayloadType *pt);
-gint payload_type_get_bitrate(PayloadType *pt);
-const gchar *payload_type_get_mime(PayloadType *pt);
-gint payload_type_get_rate(PayloadType *pt);
+bool_t payload_type_enabled(struct _PayloadType *pt);
+bool_t payload_type_check_usable(struct _PayloadType *pt, const struct _LinphoneCore *lc);
+void payload_type_set_enable(struct _PayloadType *pt,int value);
+const char *payload_type_get_description(struct _PayloadType *pt);
+int payload_type_get_bitrate(PayloadType *pt);
+const char *payload_type_get_mime(PayloadType *pt);
+int payload_type_get_rate(PayloadType *pt);
 
 
-
-#define CONNECTION_TYPE_28KMODEM 0
-#define CONNECTION_TYPE_56KMODEM 1
-#define CONNECTION_TYPE_NUMERIS 2
-#define CONNECTION_TYPE_ADSL 3
-#define CONNECTION_TYPE_ETHERNET 4
-
-extern const double bandwidths[5];
-
 struct _LpConfig;
 
 typedef struct sip_config
 {
-	gchar *contact;
-	gchar *guessed_contact;
-	gint sip_port;
-	GList *proxies;
-	GList *deleted_proxies;
+	char *contact;
+	char *guessed_contact;
+	int sip_port;
+	MSList *proxies;
+	MSList *deleted_proxies;
 	int inc_timeout;	/*timeout after an un-answered incoming call is rejected*/
-	gboolean use_info;
-	gboolean guess_hostname;
-	gboolean loopback_only;
-	gboolean ipv6_enabled;
+	bool_t use_info;
+	bool_t guess_hostname;
+	bool_t loopback_only;
+	bool_t ipv6_enabled;
 } sip_config_t;
 
 typedef struct rtp_config
 {
-	guint16 audio_rtp_port;
-	guint16 video_rtp_port;
-	gint audio_jitt_comp;  /*jitter compensation*/
-	gint video_jitt_comp;  /*jitter compensation*/
+	int audio_rtp_port;
+	int video_rtp_port;
+	int audio_jitt_comp;  /*jitter compensation*/
+	int video_jitt_comp;  /*jitter compensation*/
 }rtp_config_t;
 
-typedef struct _interface_t
-{
-	char name[20];
-#ifdef INET6
-	int  family;
-	char ipaddr[40];
-#else
-	char ip4addr[20];
-#endif
-	int index;
-} interface_t;
+
 
 typedef struct net_config
 {
-	GList *interfaces;	/* list of interface_t */
-	interface_t *sel_if;
-	double bandwidth; 		/* the bandwidth in bit/s of the selected interface*/ /*unused*/
-	gchar *nat_address;
-	gboolean use_nat;
-	gint con_type;			/* type of connection 28k 56k 128k adsl ...*/
+	char *nat_address;
+	char *stun_server;
+	int download_bw;
+	int upload_bw;
+	int con_type;			/* type of connection 28k 56k 128k adsl ...*/
+	bool_t use_nat;
+	bool_t stun_enabled;
 }net_config_t;
 
 
 typedef struct sound_config
 {
-	int ring_sndcard;	/* the playback sndcard currently used */
-	int play_sndcard;	/* the playback sndcard currently used */
-	int capt_sndcard; /* the capture sndcard currently used */
-	gint latency;	/* latency in samples of the current used sound device */
+	struct _MSSndCard * ring_sndcard;	/* the playback sndcard currently used */
+	struct _MSSndCard * play_sndcard;	/* the playback sndcard currently used */
+	struct _MSSndCard * capt_sndcard; /* the capture sndcard currently used */
+	const char **cards;
+	int latency;	/* latency in samples of the current used sound device */
 	char rec_lev;
 	char play_lev;
 	char ring_lev;
@@ -132,39 +93,38 @@ typedef struct sound_config
 	char pad;
 	char *local_ring;
 	char *remote_ring;
-	gchar *alsadev;	/* for people who wants to override the default plughw:0,0 choice*/
-	int autokill:1;  /* 1= automatically free access to sound device by killing artsd and esd*/
+	bool_t ec;
 } sound_config_t;
 
 typedef struct codecs_config
 {
-	GList *audio_codecs;  /* list of audio codecs in order of preference*/
-	GList *video_codecs;	/* for later use*/
+	MSList *audio_codecs;  /* list of audio codecs in order of preference*/
+	MSList *video_codecs;	/* for later use*/
 }codecs_config_t;
 
 typedef struct video_config{
-	gchar *device;
-	gboolean enabled;
-	gboolean show_local;
+	char *device;
+	bool_t enabled;
+	bool_t show_local;
 }video_config_t;
 
 typedef struct ui_config
 {
 	int is_daemon;
 	int is_applet;
-	guint timer_id;  /* the timer id for registration */
+	unsigned int timer_id;  /* the timer id for registration */
 }ui_config_t;
 
 
 
 typedef struct autoreplier_config
 {
-	gint enabled;
-	gint after_seconds;		/* accept the call after x seconds*/
-	gint max_users;			/* maximum number of user that can call simultaneously */
-	gint max_rec_time;  	/* the max time of incoming voice recorded */
-	gint max_rec_msg;		/* maximum number of recorded messages */
-	const gchar *message;		/* the path of the file to be played */
+	int enabled;
+	int after_seconds;		/* accept the call after x seconds*/
+	int max_users;			/* maximum number of user that can call simultaneously */
+	int max_rec_time;  	/* the max time of incoming voice recorded */
+	int max_rec_msg;		/* maximum number of recorded messages */
+	const char *message;		/* the path of the file to be played */
 }autoreplier_config_t;
 
 
@@ -203,7 +163,7 @@ typedef struct _LinphoneCall
 	struct _sdp_context *sdpctx;
 	time_t start_time;
 	LCState	state;
-	gboolean auth_pending;	
+	bool_t auth_pending;	
 } LinphoneCall;
 
 LinphoneCall * linphone_call_new_outgoing(struct _LinphoneCore *lc, const osip_from_t *from, const osip_to_t *to);
@@ -236,7 +196,7 @@ void linphone_call_log_completed(LinphoneCallLog *calllog, LinphoneCall *call);
 void linphone_call_log_destroy(LinphoneCallLog *cl);
 
 /*public: */
-gchar * linphone_call_log_to_str(LinphoneCallLog *cl);
+char * linphone_call_log_to_str(LinphoneCallLog *cl);
 
 typedef enum{
 	LinphoneSPWait,
@@ -253,23 +213,23 @@ typedef struct _LinphoneFriend{
 	LinphoneSubscribePolicy pol;
 	struct _LinphoneProxyConfig *proxy;
 	struct _LinphoneCore *lc;
-	gboolean subscribe;
-	gboolean inc_subscribe_pending;
+	bool_t subscribe;
+	bool_t inc_subscribe_pending;
 }LinphoneFriend;	
 
 LinphoneFriend * linphone_friend_new();
-LinphoneFriend *linphone_friend_new_with_addr(const gchar *addr);
-gint linphone_friend_set_sip_addr(LinphoneFriend *fr, const gchar *name);
-gint linphone_friend_send_subscribe(LinphoneFriend *fr, gboolean val);
-gint linphone_friend_set_inc_subscribe_policy(LinphoneFriend *fr, LinphoneSubscribePolicy pol);
-gint linphone_friend_set_proxy(LinphoneFriend *fr, struct _LinphoneProxyConfig *cfg);
+LinphoneFriend *linphone_friend_new_with_addr(const char *addr);
+int linphone_friend_set_sip_addr(LinphoneFriend *fr, const char *name);
+int linphone_friend_send_subscribe(LinphoneFriend *fr, bool_t val);
+int linphone_friend_set_inc_subscribe_policy(LinphoneFriend *fr, LinphoneSubscribePolicy pol);
+int linphone_friend_set_proxy(LinphoneFriend *fr, struct _LinphoneProxyConfig *cfg);
 void linphone_friend_edit(LinphoneFriend *fr);
 void linphone_friend_done(LinphoneFriend *fr);
 void linphone_friend_destroy(LinphoneFriend *lf);
 /* memory returned by those 3 functions must be freed */
-gchar *linphone_friend_get_name(LinphoneFriend *lf);
-gchar *linphone_friend_get_addr(LinphoneFriend *lf);
-gchar *linphone_friend_get_url(LinphoneFriend *lf);	/* name <sip address> */
+char *linphone_friend_get_name(LinphoneFriend *lf);
+char *linphone_friend_get_addr(LinphoneFriend *lf);
+char *linphone_friend_get_url(LinphoneFriend *lf);	/* name <sip address> */
 #define linphone_friend_url(lf) ((lf)->url)
 
 void linphone_friend_write_to_config_file(struct _LpConfig *config, LinphoneFriend *lf, int index);
@@ -278,29 +238,29 @@ LinphoneFriend * linphone_friend_new_from_config_file(struct _LinphoneCore *lc,
 typedef struct _LinphoneProxyConfig
 {
 	struct _LinphoneCore *lc;
-	gchar *reg_proxy;
-	gchar *reg_identity;
-	gchar *reg_route;
-	gchar *realm;
+	char *reg_proxy;
+	char *reg_identity;
+	char *reg_route;
+	char *realm;
 	int expires;
 	int reg_time;
 	int rid;
-	gboolean frozen;
-	gboolean reg_sendregister;
-	gboolean auth_pending;
-	gboolean registered;
-	gboolean publish;
+	bool_t frozen;
+	bool_t reg_sendregister;
+	bool_t auth_pending;
+	bool_t registered;
+	bool_t publish;
 } LinphoneProxyConfig;
 
-LinphoneProxyConfig *linphone_proxy_config_new(const gchar *server_addr);
-gint linphone_proxy_config_set_server_addr(LinphoneProxyConfig *obj, const gchar *server_addr);
-void linphone_proxy_config_set_identity(LinphoneProxyConfig *obj, const gchar *identity);
-void linphone_proxy_config_set_route(LinphoneProxyConfig *obj, const gchar *route);
-void linphone_proxy_config_expires(LinphoneProxyConfig *obj, const gint expires);
-void linphone_proxy_config_enableregister(LinphoneProxyConfig *obj, gboolean val);
+LinphoneProxyConfig *linphone_proxy_config_new(const char *server_addr);
+int linphone_proxy_config_set_server_addr(LinphoneProxyConfig *obj, const char *server_addr);
+void linphone_proxy_config_set_identity(LinphoneProxyConfig *obj, const char *identity);
+void linphone_proxy_config_set_route(LinphoneProxyConfig *obj, const char *route);
+void linphone_proxy_config_expires(LinphoneProxyConfig *obj, const int expires);
+void linphone_proxy_config_enableregister(LinphoneProxyConfig *obj, bool_t val);
 void linphone_proxy_config_edit(LinphoneProxyConfig *obj);
 void linphone_proxy_config_done(LinphoneProxyConfig *obj);
-void linphone_proxy_config_enable_publish(LinphoneProxyConfig *obj, gboolean val);
+void linphone_proxy_config_enable_publish(LinphoneProxyConfig *obj, bool_t val);
 #define linphone_proxy_config_get_route(obj)  ((obj)->reg_route)
 #define linphone_proxy_config_get_identity(obj)	((obj)->reg_identity)
 #define linphone_proxy_config_publish_enabled(obj) ((obj)->publish)
@@ -313,17 +273,17 @@ void linphone_proxy_config_write_to_config_file(struct _LpConfig* config,Linphon
 
 typedef struct _LinphoneAuthInfo
 {
-	gchar *username;
-	gchar *realm;
-	gchar *userid;
-	gchar *passwd;
-	gchar *ha1;
-	gboolean works;
+	char *username;
+	char *realm;
+	char *userid;
+	char *passwd;
+	char *ha1;
+	bool_t works;
 }LinphoneAuthInfo;
 
-LinphoneAuthInfo *linphone_auth_info_new(const gchar *username, const gchar *userid,
-				   										const gchar *passwd, const gchar *ha1,const gchar *realm);
-void linphone_auth_info_set_passwd(LinphoneAuthInfo *info, const gchar *passwd);
+LinphoneAuthInfo *linphone_auth_info_new(const char *username, const char *userid,
+				   										const char *passwd, const char *ha1,const char *realm);
+void linphone_auth_info_set_passwd(LinphoneAuthInfo *info, const char *passwd);
 /* you don't need those function*/
 void linphone_auth_info_destroy(LinphoneAuthInfo *info);
 LinphoneAuthInfo * linphone_auth_info_new_from_config_file(struct _LpConfig *config, int pos);
@@ -332,29 +292,30 @@ struct _LinphoneChatRoom{
 	struct _LinphoneCore *lc;
 	char  *peer;
 	osip_from_t *peer_url;
-	gpointer user_data;
+	void * user_data;
 };
 typedef struct _LinphoneChatRoom LinphoneChatRoom;
 
 LinphoneChatRoom * linphone_core_create_chat_room(struct _LinphoneCore *lc, const char *to);
 void linphone_chat_room_send_message(LinphoneChatRoom *cr, const char *msg);
 void linphone_chat_room_destroy(LinphoneChatRoom *cr);
-void linphone_chat_room_set_user_data(LinphoneChatRoom *cr, gpointer ud);
-gpointer linphone_chat_room_get_user_data(LinphoneChatRoom *cr);
+void linphone_chat_room_set_user_data(LinphoneChatRoom *cr, void * ud);
+void * linphone_chat_room_get_user_data(LinphoneChatRoom *cr);
 
 typedef void (*ShowInterfaceCb)(struct _LinphoneCore *lc);
 typedef void (*InviteReceivedCb)(struct _LinphoneCore *lc, const char *from);
 typedef void (*ByeReceivedCb)(struct _LinphoneCore *lc, const char *from);
-typedef void (*DisplayStatusCb)(struct _LinphoneCore *lc, char *message);
-typedef void (*DisplayMessageCb)(struct _LinphoneCore *lc, char *message);
-typedef void (*DisplayUrlCb)(struct _LinphoneCore *lc, char *message,char *url);
-typedef void (*DisplayQuestionCb)(struct _LinphoneCore *lc, char *message);
-typedef void (*LinphoneCoreCbFunc)(struct _LinphoneCore *lc,gpointer user_data);
+typedef void (*DisplayStatusCb)(struct _LinphoneCore *lc, const char *message);
+typedef void (*DisplayMessageCb)(struct _LinphoneCore *lc, const char *message);
+typedef void (*DisplayUrlCb)(struct _LinphoneCore *lc, const char *message, const char *url);
+typedef void (*DisplayQuestionCb)(struct _LinphoneCore *lc, const char *message);
+typedef void (*LinphoneCoreCbFunc)(struct _LinphoneCore *lc,void * user_data);
 typedef void (*NotifyReceivedCb)(struct _LinphoneCore *lc, LinphoneFriend * fid, const char *url, const char *status, const char *img);
 typedef void (*NewUnknownSubscriberCb)(struct _LinphoneCore *lc, LinphoneFriend *lf, const char *url);
 typedef void (*AuthInfoRequested)(struct _LinphoneCore *lc, const char *realm, const char *username);
 typedef void (*CallLogUpdated)(struct _LinphoneCore *lc, struct _LinphoneCallLog *newcl);
-typedef void (*TextMessageReceived)(struct _LinphoneCore *lc, LinphoneChatRoom *room, const gchar *from, const gchar *message);
+typedef void (*TextMessageReceived)(struct _LinphoneCore *lc, LinphoneChatRoom *room, const char *from, const char *message);
+
 typedef struct _LinphoneVTable
 {
 	ShowInterfaceCb show;
@@ -379,7 +340,7 @@ typedef struct _LinphoneVTable
 typedef struct _LCCallbackObj
 {
   LinphoneCoreCbFunc _func;
-  gpointer _user_data;
+  void * _user_data;
 }LCCallbackObj;
 
 typedef enum _LinphoneOnlineStatus{
@@ -410,29 +371,31 @@ typedef struct _LinphoneCore
 	ui_config_t ui_conf;
 	autoreplier_config_t autoreplier_conf;
 	LinphoneProxyConfig *default_proxy;
-	GList *friends;
-	GList *auth_info;
+	MSList *friends;
+	MSList *auth_info;
 	struct _RingStream *ringstream;
 	LCCallbackObj preview_finished_cb;
-	gboolean preview_finished;
+	bool_t preview_finished;
 	LinphoneCall *call;   /* the current call, in the future it will be a list of calls (conferencing)*/
 	int rid; /*registration id*/
-	GList *queued_calls;	/* used by the autoreplier */
-	GList *call_logs;
-	GList *chatrooms;
+	MSList *queued_calls;	/* used by the autoreplier */
+	MSList *call_logs;
+	MSList *chatrooms;
 	int max_call_logs;
 	int missed_calls;
 	struct _AudioStream *audiostream;  /**/
 	struct _VideoStream *videostream;
 	struct _VideoStream *previewstream;
 	struct _RtpProfile *local_profile;
-	GList *subscribers;	/* unknown subscribers */
+	MSList *subscribers;	/* unknown subscribers */
 	int minutes_away;
 	LinphoneOnlineStatus	presence_mode;
 	char *alt_contact;
-	int in_main_thread;
 	void *data;
-	GMutex *lock;
+	ms_mutex_t lock;
+	char *play_file;
+	char *rec_file;
+	bool_t use_files;
 #ifdef VINCENT_MAURY_RSVP
 	/* QoS parameters*/
 	int rsvp_enable;
@@ -440,51 +403,53 @@ typedef struct _LinphoneCore
 #endif
 } LinphoneCore;
 
+#define LINPHONE_IPADDR_SIZE 64
 
-/* The legacy API */
+/* THE main API */
 
 void linphone_core_enable_logs(FILE *file);
 void linphone_core_disable_logs();
 
-LinphoneCore *linphone_core_new(LinphoneCoreVTable *vtable,
-						const gchar *config_path, gpointer userdata);
+LinphoneCore *linphone_core_new(const LinphoneCoreVTable *vtable,
+						const char *config_path, void* userdata);
 
-void linphone_core_init(LinphoneCore *lc,LinphoneCoreVTable *vtable,
-						const gchar *config_path, gpointer userdata);
+void linphone_core_init(LinphoneCore *lc, const LinphoneCoreVTable *vtable,
+						const char *config_path, void * userdata);
 
-int linphone_core_set_primary_contact(LinphoneCore *lc, const gchar *contact);
+/* function to be periodically called in a main loop */
+void linphone_core_iterate(LinphoneCore *lc);
 
-const gchar *linphone_core_get_primary_contact(LinphoneCore *lc);
+int linphone_core_invite(LinphoneCore *lc, const char *url);
 
-void linphone_core_set_guess_hostname(LinphoneCore *lc, gboolean val);
-gboolean linphone_core_get_guess_hostname(LinphoneCore *lc);
+int linphone_core_refer(LinphoneCore *lc, const char *url);
 
-gboolean linphone_core_ipv6_enabled(LinphoneCore *lc);
-void linphone_core_enable_ipv6(LinphoneCore *lc, gboolean val);
+bool_t linphone_core_inc_invite_pending(LinphoneCore*lc);
+
+int linphone_core_accept_call(LinphoneCore *lc, const char *url);
+
+int linphone_core_terminate_call(LinphoneCore *lc, const char *url);
+
+void linphone_core_send_dtmf(LinphoneCore *lc,char dtmf);
+
+int linphone_core_set_primary_contact(LinphoneCore *lc, const char *contact);
+
+const char *linphone_core_get_primary_contact(LinphoneCore *lc);
+
+void linphone_core_set_guess_hostname(LinphoneCore *lc, bool_t val);
+bool_t linphone_core_get_guess_hostname(LinphoneCore *lc);
+
+bool_t linphone_core_ipv6_enabled(LinphoneCore *lc);
+void linphone_core_enable_ipv6(LinphoneCore *lc, bool_t val);
 
 osip_from_t *linphone_core_get_primary_contact_parsed(LinphoneCore *lc);
 
+/*0= no bandwidth limit*/
+void linphone_core_set_download_bandwidth(LinphoneCore *lc, int bw);
+void linphone_core_set_upload_bandwidth(LinphoneCore *lc, int bw);
 
-#ifdef LINPHONE_DEPRECATED
-GList * linphone_core_get_net_interfaces(LinphoneCore *lc);
+int linphone_core_get_download_bandwidth(const LinphoneCore *lc);
+int linphone_core_get_upload_bandwidth(const LinphoneCore *lc);
 
-interface_t * linphone_core_get_selected_interface(LinphoneCore *lc);
-
-#ifdef INET6
-void linphone_core_select_net_interface(LinphoneCore *lc, gint index);
-#else
-void linphone_core_select_net_interface(LinphoneCore *lc, gchar *ifname);
-#endif
-
-#endif
-
-void linphone_core_set_connection_type(LinphoneCore *lc, int type);
-
-int linphone_core_get_connection_type(LinphoneCore *lc);
-
-int linphone_core_invite(LinphoneCore *lc, const gchar *url);
-
-int linphone_core_refer(LinphoneCore *lc, const gchar *url);
 
 #ifdef VINCENT_MAURY_RSVP
 /* QoS functions */
@@ -492,29 +457,23 @@ int linphone_core_set_rpc_mode(LinphoneCore *lc, int on); /* on = 1 (RPC_ENABLE
 int linphone_core_set_rsvp_mode(LinphoneCore *lc, int on); /* on = 1 (RSVP_ENABLE = 1) */
 int linphone_core_change_qos(LinphoneCore *lc, int answer); /* answer = 1 for yes, 0 for no */
 #endif
-gboolean linphone_core_inc_invite_pending(LinphoneCore*lc);
 
-int linphone_core_accept_call(LinphoneCore *lc, const char *url);
+/* returns a MSList of PayloadType */
+const MSList *linphone_core_get_audio_codecs(LinphoneCore *lc);
 
-int linphone_core_terminate_call(LinphoneCore *lc, const char *url);
+int linphone_core_set_audio_codecs(LinphoneCore *lc, MSList *codecs);
+/* returns a MSList of PayloadType */
+const MSList *linphone_core_get_video_codecs(LinphoneCore *lc);
 
-void linphone_core_send_dtmf(LinphoneCore *lc,gchar dtmf);
+int linphone_core_set_video_codecs(LinphoneCore *lc, MSList *codecs);
 
-/* returns a GList of MSCodecInfo */
-GList *linphone_core_get_audio_codecs(LinphoneCore *lc);
-
-int linphone_core_set_audio_codecs(LinphoneCore *lc, GList *codecs);
-
-/* returns a GList of MSCodecInfo */
-GList *linphone_core_get_video_codecs(LinphoneCore *lc);
-
-int linphone_core_set_video_codecs(LinphoneCore *lc, GList *codecs);
+bool_t linphone_core_check_payload_type_usability(const LinphoneCore *lc, PayloadType *pt);
 
 void linphone_core_add_proxy_config(LinphoneCore *lc, LinphoneProxyConfig *config);
 
 void linphone_core_remove_proxy_config(LinphoneCore *lc, LinphoneProxyConfig *config);
 
-GList *linphone_core_get_proxy_config_list(LinphoneCore *lc);
+MSList *linphone_core_get_proxy_config_list(LinphoneCore *lc);
 
 void linphone_core_set_default_proxy(LinphoneCore *lc, LinphoneProxyConfig *config);
 
@@ -538,9 +497,9 @@ void linphone_core_set_audio_port(LinphoneCore *lc, int port);
 
 void linphone_core_set_video_port(LinphoneCore *lc, int port);
 
-void linphone_core_set_use_info_for_dtmf(LinphoneCore *lc, gboolean use_info);
+void linphone_core_set_use_info_for_dtmf(LinphoneCore *lc, bool_t use_info);
 
-gboolean linphone_core_get_use_info_for_dtmf(LinphoneCore *lc);
+bool_t linphone_core_get_use_info_for_dtmf(LinphoneCore *lc);
 
 int linphone_core_get_sip_port(LinphoneCore *lc);
 
@@ -550,69 +509,82 @@ void linphone_core_set_inc_timeout(LinphoneCore *lc, int seconds);
 
 int linphone_core_get_inc_timeout(LinphoneCore *lc);
 
+void linphone_core_set_stun_server(LinphoneCore *lc, const char *server);
+
+const char * linphone_core_get_stun_server(const LinphoneCore *lc);
+
+void linphone_core_enable_stun(LinphoneCore *lc, bool_t val);
+
+bool_t linphone_core_stun_enabled(const LinphoneCore *lc);
+
 /* give a NULL addr to only set nat use */
-void linphone_core_set_nat_address(LinphoneCore *lc, const gchar *addr, gboolean use);
+void linphone_core_set_nat_address(LinphoneCore *lc, const char *addr);
 
-const gchar *linphone_core_get_nat_address(LinphoneCore *lc, gboolean *use);
+const char *linphone_core_get_nat_address(LinphoneCore *lc);
 
-const gchar *linphone_core_get_nat_address_if_used(LinphoneCore *lc);
+void linphone_core_use_nat_address(LinphoneCore *lc, bool_t val);
 
-void linphone_core_force_ip_address(LinphoneCore *lc, const gchar *ipaddr);
+bool_t linphone_core_nat_address_used(const LinphoneCore *lc);
 
-/* function to be periodically called in a main loop */
-void linphone_core_iterate(LinphoneCore *lc);
+const char *linphone_core_get_nat_address_if_used(LinphoneCore *lc);
 
 /* sound functions */
-SndCardManager * linphone_core_get_card_manager(LinphoneCore *lc);
-gint linphone_core_get_ring_level(LinphoneCore *lc);
-gint linphone_core_get_play_level(LinphoneCore *lc);
-gint linphone_core_get_rec_level(LinphoneCore *lc);
-void linphone_core_set_ring_level(LinphoneCore *lc, gint level);
-void linphone_core_set_play_level(LinphoneCore *lc, gint level);
-void linphone_core_set_rec_level(LinphoneCore *lc, gint level);
-gint linphone_core_get_ringer_device(LinphoneCore *lc);
-gint linphone_core_get_playback_device(LinphoneCore *lc);
-gint linphone_core_get_capture_device(LinphoneCore *lc);
-gint linphone_core_set_ringer_device(LinphoneCore *lc, gint devid);
-gint linphone_core_set_playback_device(LinphoneCore *lc, gint devid);
-gint linphone_core_set_capture_device(LinphoneCore *lc, gint devid);
-gint linphone_core_set_ringer_device_from_name(LinphoneCore *lc, const gchar *name);
-gint linphone_core_set_playback_device_from_name(LinphoneCore *lc, const gchar *name);
-gint linphone_core_set_capture_device_from_name(LinphoneCore *lc, const gchar *name);
-gchar linphone_core_get_sound_source(LinphoneCore *lc);
-void linphone_core_set_sound_source(LinphoneCore *lc, gchar source);
-void linphone_core_set_ring(LinphoneCore *lc, const gchar *path);
-gchar *linphone_core_get_ring(LinphoneCore *lc);
-gint linphone_core_preview_ring(LinphoneCore *lc, const gchar *ring,LinphoneCoreCbFunc func,gpointer userdata);
+/* returns a null terminated static array of string describing the sound devices */ 
+const char**  linphone_core_get_sound_devices(LinphoneCore *lc);
+int linphone_core_get_ring_level(LinphoneCore *lc);
+int linphone_core_get_play_level(LinphoneCore *lc);
+int linphone_core_get_rec_level(LinphoneCore *lc);
+void linphone_core_set_ring_level(LinphoneCore *lc, int level);
+void linphone_core_set_play_level(LinphoneCore *lc, int level);
+void linphone_core_set_rec_level(LinphoneCore *lc, int level);
+const char * linphone_core_get_ringer_device(LinphoneCore *lc);
+const char * linphone_core_get_playback_device(LinphoneCore *lc);
+const char * linphone_core_get_capture_device(LinphoneCore *lc);
+int linphone_core_set_ringer_device(LinphoneCore *lc, const char * devid);
+int linphone_core_set_playback_device(LinphoneCore *lc, const char * devid);
+int linphone_core_set_capture_device(LinphoneCore *lc, const char * devid);
+char linphone_core_get_sound_source(LinphoneCore *lc);
+void linphone_core_set_sound_source(LinphoneCore *lc, char source);
+void linphone_core_set_ring(LinphoneCore *lc, const char *path);
+char *linphone_core_get_ring(LinphoneCore *lc);
+int linphone_core_preview_ring(LinphoneCore *lc, const char *ring,LinphoneCoreCbFunc func,void * userdata);
 typedef enum {RINGBACK_TYPE_FR,RINGBACK_TYPE_US} RingBackType;
 void linphone_core_set_ringback(LinphoneCore *lc,RingBackType type);
 RingBackType linphone_core_get_ringback(LinphoneCore *lc);
+void linphone_core_enable_echo_cancelation(LinphoneCore *lc, bool_t val);
+bool_t linphone_core_echo_cancelation_enabled(LinphoneCore *lc);
 
-void linphone_core_set_presence_info(LinphoneCore *lc,gint minutes_away,
-													const gchar *contact,
-													LinphoneOnlineStatus os);
+void linphone_core_set_presence_info(LinphoneCore *lc,int minutes_away,const char *contact,LinphoneOnlineStatus os);
 
 void linphone_core_add_friend(LinphoneCore *lc, LinphoneFriend *fr);
 void linphone_core_remove_friend(LinphoneCore *lc, LinphoneFriend *fr);
 void linphone_core_reject_subscriber(LinphoneCore *lc, LinphoneFriend *lf);
 /* a list of LinphoneFriend */
-GList * linphone_core_get_friend_list(LinphoneCore *lc);
+MSList * linphone_core_get_friend_list(LinphoneCore *lc);
 /* notify all friends that have subscribed */
 void linphone_core_notify_all_friends(LinphoneCore *lc, LinphoneOnlineStatus os);
 
 /* returns a list of LinphoneCallLog */
-GList * linphone_core_get_call_logs(LinphoneCore *lc);
+MSList * linphone_core_get_call_logs(LinphoneCore *lc);
 
 /* video support */
-void linphone_core_enable_video(LinphoneCore *lc, gboolean val);
-gboolean linphone_core_video_enabled(LinphoneCore *lc);
+void linphone_core_enable_video(LinphoneCore *lc, bool_t val);
+bool_t linphone_core_video_enabled(LinphoneCore *lc);
 
-void linphone_core_enable_video_preview(LinphoneCore *lc, gboolean val);
-gboolean linphone_core_video_preview_enabled(LinphoneCore *lc);
+/*play/record support: use files instead of soundcard*/
+void linphone_core_use_files(LinphoneCore *lc, bool_t yesno);
+void linphone_core_set_play_file(LinphoneCore *lc, const char *file);
+void linphone_core_set_record_file(LinphoneCore *lc, const char *file);
 
-int linphone_core_set_video_device(LinphoneCore *lc, const gchar *method, const gchar *device);
 
-gboolean linphone_core_is_in_main_thread(LinphoneCore *lc);
+/*
+void linphone_core_enable_video_preview(LinphoneCore *lc, bool_t val);
+bool_t linphone_core_video_preview_enabled(LinphoneCore *lc);
+*/
+
+int linphone_core_set_video_device(LinphoneCore *lc, const char *method, const char *device);
+
+bool_t linphone_core_is_in_main_thread(LinphoneCore *lc);
 
 void *linphone_core_get_user_data(LinphoneCore *lc);
 
@@ -626,15 +598,13 @@ void linphone_core_destroy(LinphoneCore *lc);
 /* end of lecacy api */
 
 /*internal use only */
-#define linphone_core_thread_enter(lc) (lc)->in_main_thread=0
-#define linphone_core_thread_leave(lc) (lc)->in_main_thread=1
-#define linphone_core_lock(lc)	g_mutex_lock((lc)->lock)
-#define linphone_core_unlock(lc)	g_mutex_unlock((lc)->lock)
+#define linphone_core_lock(lc)	ms_mutex_lock(&(lc)->lock)
+#define linphone_core_unlock(lc)	ms_mutex_unlock((&lc)->lock)
 void linphone_core_start_media_streams(LinphoneCore *lc, LinphoneCall *call);
 void linphone_core_stop_media_streams(LinphoneCore *lc);
 const char * linphone_core_get_identity(LinphoneCore *lc);
 const char * linphone_core_get_route(LinphoneCore *lc);
-gboolean linphone_core_interpret_url(LinphoneCore *lc, const char *url, char **real_url, osip_to_t **real_parsed_url);
+bool_t linphone_core_interpret_url(LinphoneCore *lc, const char *url, char **real_url, osip_to_t **real_parsed_url);
 
 #ifdef __cplusplus
 }
