@@ -1,7 +1,7 @@
 
 /*
 linphone
-Copyright (C) 2000  Simon MORLAT (simon.morlat@free.fr)
+Copyright (C) 2000  Simon MORLAT (simon.morlat@linphone.org)
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -18,9 +18,8 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
-#include "misc.h"
-#include <mediastream.h>
-#include <mscodec.h>
+#include "private.h"
+#include "mediastreamer2/mediastream.h"
 #include <stdlib.h>
 #include <stdio.h>
 #include <signal.h>
@@ -29,14 +28,11 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <unistd.h>
 #include <fcntl.h>
 
-#ifdef INET6
-#include <sys/socket.h>
-#include <netdb.h>
-#endif
+
+#ifndef WIN32
 
 static char lock_name[80];
 static char lock_set=0;
-
 /* put a lock file in /tmp. this is called when linphone runs as a daemon*/
 int set_lock_file()
 {
@@ -66,7 +62,7 @@ int get_lock_file()
 	if (lockfile==NULL)
 		return(-1);
 	if (fscanf(lockfile,"%i",&pid)!=1){
-		g_warning("Could not read pid in lock file.");
+		ms_warning("Could not read pid in lock file.");
 		fclose(lockfile);
 		return -1;
 	}
@@ -86,155 +82,19 @@ int remove_lock_file()
 	return(err);
 }
 
-static int esd_killed=0;
-static int artsd_killed=0;
-
-int kill_sound_daemons()
-{
-	char *command;
-	int err;
-	FILE *out;
-	pid_t pid;
-	
-	/* try to kill all artsd*/
-	command=g_strdup_printf("ps -u %s |grep artsd",getenv("LOGNAME"));
-	out=popen(command,"r");
-	if (out!=NULL)
-	{
-		do{
-			err=fscanf(out,"%i",&pid);
-			if (err==1) {
-				if (linphone_arts_suspend()<0) kill(pid,SIGINT);
-				artsd_killed=1;
-			}
-		}while(err==1);
-		pclose(out);
-	}
-	g_free(command);
-	/* kill aplay, because for some reason on kde3 it is spawned when artsd dies*/
-	command=g_strdup_printf("ps -u %s |grep aplay",getenv("LOGNAME"));
-	out=popen(command,"r");
-	if (out!=NULL)
-	{
-		do{
-			err=fscanf(out,"%i",&pid);
-			if (err==1) {
-				kill(pid,SIGINT);
-			}
-		}while(err==1);
-		pclose(out);
-	}
-	g_free(command);
-	
-	/* do the same with esd*/
-	command=g_strdup_printf("ps -u %s |grep esd",getenv("LOGNAME"));
-	out=popen(command,"r");
-	if (out!=NULL)
-	{
-		do{
-			err=fscanf(out,"%i",&pid);
-			if (err==1) {
-				kill(pid,SIGINT);
-				esd_killed=1;
-			}
-		}while(err==1);
-		pclose(out);
-	}
-	g_free(command);
-	return(0);
-}
-
-void restore_sound_daemons()
-{
-	if (esd_killed){
-		esd_killed=0;
-		g_message("Restarting esd...");
-		g_spawn_command_line_async("esd",NULL);
-	}
-	if (artsd_killed){
-		artsd_killed=0;
-		g_message("Restarting artsd...");
-		if (linphone_arts_restore()<0) g_spawn_command_line_async("artsd",NULL);
-	}
-}
-
-
-/*try to open dsp. If failed, kill sound daemons if allowed by user, and try agin. If fail again, display the error message. Close it in success*/
-int __try_open_dsp(LinphoneCore *lc, int devid)
-{
-	int err1,err2,retval=-1;
-	
-	err1=test_audio_dev(devid);
-	
-	if (err1>=0){
-		retval=err1;
-		goto end;
-	}
-	
-	switch (err1){
-		case -ENODEV: /* no such device */
-		case -ENOENT: /* no such file */
-			return err1;
-	}
-	
-	/* else it is probably EWOULDBLOCK, EAGAIN */	
-	if (lc->sound_conf.autokill)
-	{
-		g_message("killing sound daemons.\n");
-		kill_sound_daemons();
-		sleep(1);   /* wait for sound daemons to be killed...*/
-	}
-	else
-	{
-		
-		return(-1);
-	}
-	err2=test_audio_dev(devid);
-	if (err2<0)
-	{
-		char *msg;
-		SndCard *sc=snd_card_manager_get_card(snd_card_manager,devid);
-		if (sc!=NULL){
-			msg=g_strdup_printf(_("Linphone could not open audio device %s. Check if your sound card is fully configured and working."),
-												snd_card_get_identifier(sc));
-			lc->vtable.display_warning(lc,msg);
-			g_free(msg);
-		}else{
-			g_warning("Fail to open undefined audio device !");
-		}
-		return(-1);
-	}
-	retval=err2;
-	
-	end:
-	if (retval>0) lc->sound_conf.latency=retval/8;
-	return retval;
-}
-
-int try_open_dsp(LinphoneCore *lc){
-	int play_dev=lc->sound_conf.play_sndcard;
-	int capt_dev=lc->sound_conf.capt_sndcard;
-	int err;
-	if (play_dev!=capt_dev) {
-		err=__try_open_dsp(lc,play_dev);
-		err=__try_open_dsp(lc,capt_dev);
-	}else err=__try_open_dsp(lc,play_dev);
-	return err;
-}
+#endif
 
 char *int2str(int number)
 {
-	gchar *numstr=g_malloc(10);
+	char *numstr=ms_malloc(10);
 	snprintf(numstr,10,"%i",number);
 	return numstr;
 }
 
-
-
 void check_sound_device(LinphoneCore *lc)
 {
 	int fd,len;
-	gint a;
+	int a;
 	char *file=NULL;
 	char *i810_audio=NULL;
 	char *snd_pcm_oss=NULL;
@@ -245,15 +105,15 @@ void check_sound_device(LinphoneCore *lc)
 	if (fd>0){
 		/* read the entire /proc/modules file and check if sound conf seems correct */
 		/*a=fstat(fd,&statbuf);
-		if (a<0) g_warning("Can't stat /proc/modules:%s.",strerror(errno));
+		if (a<0) ms_warning("Can't stat /proc/modules:%s.",strerror(errno));
 		len=statbuf.st_size;
-		if (len==0) g_warning("/proc/modules has zero size!");
+		if (len==0) ms_warning("/proc/modules has zero size!");
 		*/
 		/***** fstat does not work on /proc/modules for unknown reason *****/
 		len=6000;
-		file=g_malloc(len+1);
+		file=ms_malloc(len+1);
 		a=read(fd,file,len);
-		if (a<len) file=g_realloc(file,a+1);
+		if (a<len) file=ms_realloc(file,a+1);
 		file[a]='\0';
 		i810_audio=strstr(file,"i810_audio");
 		if (i810_audio!=NULL){
@@ -274,8 +134,8 @@ void check_sound_device(LinphoneCore *lc)
 			}
 		}
 	}else {
-#ifdef __LINUX__
-		g_warning("Could not open /proc/modules.");
+#ifdef __linux
+		ms_warning("Could not open /proc/modules.");
 #endif
 	}
 	/* now check general volume. Some user forget to rise it and then complain that linphone is
@@ -284,13 +144,13 @@ void check_sound_device(LinphoneCore *lc)
 	if (lc->sound_conf.sndcard!=NULL){
 		a=snd_card_get_level(lc->sound_conf.sndcard,SND_CARD_LEVEL_GENERAL);
 		if (a<50){
-			g_warning("General level is quite low (%i). Linphone rises it up for you.",a);
+			ms_warning("General level is quite low (%i). Linphone rises it up for you.",a);
 			snd_card_set_level(lc->sound_conf.sndcard,SND_CARD_LEVEL_GENERAL,80);
 		}
 	}
 	*/
 	end:
-	if (file!=NULL) g_free(file);
+	if (file!=NULL) ms_free(file);
 	if (fd>0) close(fd);
 }
 
@@ -298,137 +158,121 @@ void check_sound_device(LinphoneCore *lc)
 #define RTP_HDR_SZ 12
 #define IP4_HDR_SZ 20   /*20 is the minimum, but there may be some options*/
 
-gchar *payload_type_get_description(PayloadType *pt){
-	if (pt->user_data!=NULL){
-		MSFilterInfo *c=(MSFilterInfo*)pt->user_data;
-		return c->description;
-	}
-	return NULL;
+const char *payload_type_get_description(PayloadType *pt){
+	return (const char *)pt->user_data;
 }	
 
-void payload_type_set_enable(PayloadType *pt,gint value) 
+void payload_type_set_enable(PayloadType *pt,int value) 
 {
 	if ((value)!=0) payload_type_set_flag(pt,PAYLOAD_TYPE_ENABLED); \
 	else payload_type_unset_flag(pt,PAYLOAD_TYPE_ENABLED); 
 }
-void payload_type_set_usable(PayloadType *pt,gint value) 
-{
-	if ((value)!=0) payload_type_set_flag(pt,PAYLOAD_TYPE_USABLE); \
-	else payload_type_unset_flag(pt,PAYLOAD_TYPE_USABLE); 
-}
 
 
-
-gboolean payload_type_enabled(PayloadType *pt) {
+bool_t payload_type_enabled(PayloadType *pt) {
 	return (((pt)->flags & PAYLOAD_TYPE_ENABLED)!=0);
 }
-gboolean payload_type_usable(PayloadType *pt) {
-	return ((pt)->flags & PAYLOAD_TYPE_USABLE);
-}
 
-gint payload_type_get_bitrate(PayloadType *pt)
+int payload_type_get_bitrate(PayloadType *pt)
 {
 	return pt->normal_bitrate;
 }
-const gchar *payload_type_get_mime(PayloadType *pt){
+const char *payload_type_get_mime(PayloadType *pt){
 	return pt->mime_type;
 }
-gint payload_type_get_rate(PayloadType *pt){
+
+int payload_type_get_rate(PayloadType *pt){
 	return pt->clock_rate;
 }
 
-
+static int get_bandwidth(const LinphoneCore *lc){
+	int dbw=linphone_core_get_download_bandwidth(lc);
+	int ubw=linphone_core_get_upload_bandwidth(lc);
+	if (dbw==0)
+		dbw=1<<30;
+	if (ubw==0)
+		ubw=1<<30;
+	return MIN(dbw,ubw);
+}
 
 
 /* return TRUE if codec can be used with bandwidth, FALSE else*/
-gboolean payload_type_check_usable(PayloadType *pt,double bandwidth)
+bool_t linphone_core_check_payload_type_usability(const LinphoneCore *lc, PayloadType *pt)
 {
-	gboolean ret=0;
+	bool_t ret=FALSE;
 	double codec_band;
 	double npacket;
 	double packet_size;
+	double bandwidth=get_bandwidth(lc)*1000.0;	
+
+	/*ms_message("Bandwidth is %g",bandwidth);*/
 	
 	switch (pt->type){
 		case PAYLOAD_AUDIO_CONTINUOUS:
 		case PAYLOAD_AUDIO_PACKETIZED:
+			if (strcmp("speex",pt->mime_type)==0 && pt->clock_rate==8000){
+				if ((bandwidth<=128000 && lc->video_conf.enabled) ||
+					bandwidth<=64000)
+					pt->normal_bitrate=8000;
+				else
+					pt->normal_bitrate=20000;
+			}
 			/* very approximative estimation... revisit*/
 			npacket=50;
 			packet_size=(double)(pt->normal_bitrate/(50*8))+UDP_HDR_SZ+RTP_HDR_SZ+IP4_HDR_SZ;
 			codec_band=packet_size*8.0*npacket;
 			ret=(codec_band<bandwidth);
-			//g_message("Payload %s: %g",pt->mime_type,codec_band);
+			//ms_message("Payload %s: %g",pt->mime_type,codec_band);
 			break;
 		case PAYLOAD_VIDEO:
-			if (bandwidth>=128000) ret=TRUE;
+			if (bandwidth>=128000) {
+				if (strcmp(pt->mime_type,"H263-1998")==0){
+					payload_type_set_recv_fmtp(pt,"CIF=1;QCIF=1");
+				}
+				/*let the video use all the bandwidth minus the maximum bandwidth used by audio */
+				if (bandwidth<=1000000)
+					pt->normal_bitrate=bandwidth-64000;
+				else 
+					pt->normal_bitrate=1000000;
+				ret=TRUE;
+			}
 			else ret=FALSE;
 			break;
 	}
-	/*if (!ret) g_warning("Payload %s is not usable with your internet connection.",pt->mime_type);*/
+	/*if (!ret) ms_warning("Payload %s is not usable with your internet connection.",pt->mime_type);*/
 	
 	return ret;
 }
 
-void linphone_core_check_codecs_for_bandwidth(LinphoneCore *lc)
+MSList *fix_codec_list(RtpProfile *prof, MSList *conflist)
 {
-	GList *elem;
-	PayloadType *pt;
-	
-	for(elem=lc->codecs_conf.audio_codecs;elem!=NULL;elem=g_list_next(elem))
-	{
-		pt=(PayloadType*)elem->data;
-		if (strcmp("speex",pt->mime_type)==0 && pt->clock_rate==8000){
-			if (lc->net_conf.bandwidth<bandwidths[CONNECTION_TYPE_NUMERIS]){
-				pt->normal_bitrate=8000;
-			}else pt->normal_bitrate=20000;
-		}	
-		payload_type_set_usable(pt,payload_type_check_usable(pt,lc->net_conf.bandwidth));	
-	}
-	for(elem=lc->codecs_conf.video_codecs;elem!=NULL;elem=g_list_next(elem))
-	{
-		pt=(PayloadType*)elem->data;
-		payload_type_set_usable(pt,payload_type_check_usable(pt,lc->net_conf.bandwidth));	
-	}
-}
-
-GList *fix_codec_list(RtpProfile *prof, GList *conflist)
-{
-	GList *elem;
-	GList *newlist=NULL;
-	MSCodecInfo *codec;
+	MSList *elem;
+	MSList *newlist=NULL;
 	PayloadType *payload,*confpayload;
-	for (elem=conflist;elem!=NULL;elem=g_list_next(elem))
+	for (elem=conflist;elem!=NULL;elem=ms_list_next(elem))
 	{
 		confpayload=(PayloadType*)elem->data;
 			
-		payload=rtp_profile_find_payload(prof,
-								confpayload->mime_type,
+		payload=rtp_profile_find_payload(prof,confpayload->mime_type,
 								confpayload->clock_rate);
 		if (payload!=NULL){
-			/*check if mediastreamer supports this payload*/
-			switch (payload->type){
-				case PAYLOAD_AUDIO_CONTINUOUS:
-				case PAYLOAD_AUDIO_PACKETIZED:
-					codec=ms_audio_codec_info_get(payload->mime_type);
-					break;
-				case PAYLOAD_VIDEO:
-					codec=ms_video_codec_info_get(payload->mime_type);
-				break;
-			default:
-				g_error("Unsupported rtp media type.");
-				codec=NULL;
-			}
-			if (codec==NULL){
-				g_warning("There is no plugin to handle %s",confpayload->mime_type);
-			}
-			else 
-			{
-				payload_type_set_user_data(payload,(gpointer)codec);
-				payload_type_set_enable(payload,payload_type_enabled(confpayload));
-				newlist=g_list_append(newlist,(gpointer)payload);
+			if (ms_filter_codec_supported(confpayload->mime_type)){
+				MSFilterDesc *desc=ms_filter_get_encoder(confpayload->mime_type);
+				if (payload_type_get_user_data(payload)==NULL){
+					payload_type_set_user_data(payload,(void*)desc->text);
+					payload_type_set_enable(payload,payload_type_enabled(confpayload));
+					/*hack: put theora first */
+					if (strcasecmp(payload->mime_type,"x-theora")==0){
+						newlist=ms_list_prepend(newlist,(void *)payload);
+					}else{
+						newlist=ms_list_append(newlist,(void *)payload);
+					}
+					
+				}/*else this is a duplicate */
 			}
 		}
 		else{
-			g_warning("Cannot support %s/%i: does not exist.",confpayload->mime_type,
+			ms_warning("Cannot support %s/%i: does not exist.",confpayload->mime_type,
 								confpayload->clock_rate);
 		}
 	}
@@ -439,11 +283,11 @@ GList *fix_codec_list(RtpProfile *prof, GList *conflist)
 void linphone_core_setup_local_rtp_profile(LinphoneCore *lc)
 {
 	int i;
-	GList *audiopt,*videopt;
-	MSCodecInfo *codec;
+	MSList *audiopt,*videopt;
 	PayloadType *payload;
+	bool_t prepend;
 	
-	lc->local_profile=&av_profile;
+	lc->local_profile=rtp_profile_clone_full(&av_profile);
 	
 	/* first look at the list given by configuration file to see if 
 	it is correct */
@@ -458,38 +302,44 @@ void linphone_core_setup_local_rtp_profile(LinphoneCore *lc)
 		if (payload!=NULL){
 			if (payload_type_get_user_data(payload)!=NULL) continue;
 			/* find a mediastreamer codec for this payload type */
-			switch (payload->type){
-				case PAYLOAD_AUDIO_CONTINUOUS:
-				case PAYLOAD_AUDIO_PACKETIZED:
-					codec=ms_audio_codec_info_get(payload->mime_type);
-					if (codec!=NULL){
-						g_message("Adding new codec %s/%i",payload->mime_type,payload->clock_rate);
-						payload_type_set_enable(payload,1);
-						payload_type_set_user_data(payload,(gpointer)codec);
-						audiopt=g_list_append(audiopt,(gpointer)payload);
-					}
-					break;
-				case PAYLOAD_VIDEO:
-					codec=ms_video_codec_info_get(payload->mime_type);
-					if (codec!=NULL){
-						payload_type_set_enable(payload,1);
-						payload_type_set_user_data(payload,(gpointer)codec);
-						videopt=g_list_append(videopt,(gpointer)payload);
-					}
-					break;
-				default:
-					g_error("Unsupported rtp media type.");
+			if (ms_filter_codec_supported(payload->mime_type)){
+				MSFilterDesc *desc=ms_filter_get_encoder(payload->mime_type);
+				ms_message("Adding new codec %s/%i",payload->mime_type,payload->clock_rate);
+				payload_type_set_enable(payload,1);
+				payload_type_set_user_data(payload,(void *)desc->text);
+				prepend=FALSE;
+				/* by default, put speex and theora on top of list*/
+				if (strcmp(payload->mime_type,"speex")==0)
+					prepend=TRUE;
+				if (strcmp(payload->mime_type,"theora")==0)
+					prepend=TRUE;
+				switch (payload->type){
+					case PAYLOAD_AUDIO_CONTINUOUS:
+					case PAYLOAD_AUDIO_PACKETIZED:
+							if (prepend)
+								audiopt=ms_list_prepend(audiopt,(void *)payload);	
+							else
+								audiopt=ms_list_append(audiopt,(void *)payload);
+						break;
+					case PAYLOAD_VIDEO:
+							if (prepend)
+								videopt=ms_list_prepend(videopt,(void *)payload);
+							else
+								videopt=ms_list_append(videopt,(void *)payload);
+						break;
+					default:
+						ms_error("Unsupported rtp media type.");
+				}
 			}
 		}
 	}
-	g_list_foreach(lc->codecs_conf.audio_codecs,(GFunc)payload_type_destroy,NULL);
-	g_list_foreach(lc->codecs_conf.video_codecs,(GFunc)payload_type_destroy,NULL);
-	g_list_free(lc->codecs_conf.audio_codecs);
-	g_list_free(lc->codecs_conf.video_codecs);
+	ms_list_for_each(lc->codecs_conf.audio_codecs,(void (*)(void*))payload_type_destroy);
+	ms_list_for_each(lc->codecs_conf.video_codecs,(void (*)(void *))payload_type_destroy);
+	ms_list_free(lc->codecs_conf.audio_codecs);
+	ms_list_free(lc->codecs_conf.video_codecs);
 	/* set the fixed lists instead:*/
 	lc->codecs_conf.audio_codecs=audiopt;
 	lc->codecs_conf.video_codecs=videopt;
-	linphone_core_check_codecs_for_bandwidth(lc);
 }
 
 int from_2char_without_params(osip_from_t *from,char **str)
@@ -508,16 +358,34 @@ int from_2char_without_params(osip_from_t *from,char **str)
 	return 0;
 }
 
+bool_t lp_spawn_command_line_sync(const char *command, char **result,int *command_ret){
+	FILE *f=popen(command,"r");
+	if (f!=NULL){
+		int err;
+		*result=ms_malloc(4096);
+		err=fread(*result,1,4096-1,f);
+		if (err<0){
+			ms_warning("Error reading command output:%s",strerror(errno));
+			ms_free(result);
+			return FALSE;
+		}
+		(*result)[err]=0;
+		err=pclose(f);
+		if (command_ret!=NULL) *command_ret=err;
+		return TRUE;
+	}
+	return FALSE;
+}
 
 #if defined(HAVE_GETIFADDRS) && defined(INET6)
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <ifaddrs.h>
-gboolean host_has_ipv6_network()
+bool_t host_has_ipv6_network()
 {
 	struct ifaddrs *ifp;
 	struct ifaddrs *ifpstart;
-	gboolean ipv6_present=FALSE;
+	bool_t ipv6_present=FALSE;
 	
 	if (getifaddrs (&ifpstart) < 0)
 	{
@@ -547,7 +415,7 @@ gboolean host_has_ipv6_network()
 }
 #else
 
-gboolean host_has_ipv6_network()
+bool_t host_has_ipv6_network()
 {
 	return FALSE;
 }
