@@ -1,6 +1,6 @@
 /*
 linphone
-Copyright (C) 2000  Simon MORLAT (simon.morlat@free.fr)
+Copyright (C) 2000  Simon MORLAT (simon.morlat@linphone.org)
 */
 /*
  *  This program is free software; you can redistribute it and/or modify
@@ -18,10 +18,11 @@ Copyright (C) 2000  Simon MORLAT (simon.morlat@free.fr)
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
  
-#include "linphonecore.h" 
+#include "linphonecore.h"
 #include <eXosip.h>
 #include <osipparser2/osip_message.h>
 #include "lpconfig.h"
+#include "private.h"
 
 
 void linphone_proxy_config_init(LinphoneProxyConfig *obj){
@@ -30,10 +31,10 @@ void linphone_proxy_config_init(LinphoneProxyConfig *obj){
 	obj->expires=600;
 }
 
-LinphoneProxyConfig *linphone_proxy_config_new(const gchar *server_addr){
+LinphoneProxyConfig *linphone_proxy_config_new(const char *server_addr){
 	LinphoneProxyConfig *obj=NULL;
 	int err;
-	obj=g_new(LinphoneProxyConfig,1);
+	obj=ms_new(LinphoneProxyConfig,1);
 	linphone_proxy_config_init(obj);
 	err=linphone_proxy_config_set_server_addr(obj,server_addr);
 	if (err<0){
@@ -44,9 +45,9 @@ LinphoneProxyConfig *linphone_proxy_config_new(const gchar *server_addr){
 }
 
 void linphone_proxy_config_destroy(LinphoneProxyConfig *obj){
-	if (obj->reg_proxy!=NULL) g_free(obj->reg_proxy);
-	if (obj->reg_identity!=NULL) g_free(obj->reg_identity);
-	if (obj->reg_route!=NULL) g_free(obj->reg_route);
+	if (obj->reg_proxy!=NULL) ms_free(obj->reg_proxy);
+	if (obj->reg_identity!=NULL) ms_free(obj->reg_identity);
+	if (obj->reg_route!=NULL) ms_free(obj->reg_route);
 }
 
 static void linphone_proxy_config_register(LinphoneProxyConfig *obj){
@@ -57,46 +58,46 @@ static void linphone_proxy_config_register(LinphoneProxyConfig *obj){
 }
 
 
-gint linphone_proxy_config_set_server_addr(LinphoneProxyConfig *obj, const gchar *server_addr){
+int linphone_proxy_config_set_server_addr(LinphoneProxyConfig *obj, const char *server_addr){
 	int err;
 	osip_from_t *url;
 	if (server_addr==NULL || strlen(server_addr)==0) return -1;
 	osip_from_init(&url);
 	err=osip_from_parse(url,server_addr);
-	if (err<0){
-		g_warning("Could not parse %s",server_addr);
+	if (err<0 || url->url->host==NULL){
+		ms_warning("Could not parse %s",server_addr);
 		osip_from_free(url);
 		return -1;
 	}else{
-		if (obj->reg_proxy!=NULL) g_free(obj->reg_proxy);
-		obj->reg_proxy=g_strdup(server_addr);
+		if (obj->reg_proxy!=NULL) ms_free(obj->reg_proxy);
+		obj->reg_proxy=ms_strdup(server_addr);
 	}
 	osip_from_free(url);
 	return 0;
 }
 
-void linphone_proxy_config_set_identity(LinphoneProxyConfig *obj, const gchar *identity){
+void linphone_proxy_config_set_identity(LinphoneProxyConfig *obj, const char *identity){
 	int err=0;
 	osip_from_t *url;
 	if (identity!=NULL && strlen(identity)>0){
 		osip_from_init(&url);
 		err=osip_from_parse(url,identity);
-		if (err<0){
-			g_warning("Could not parse %s",identity);
+		if (err<0 || url->url->host==NULL || url->url->username==NULL){
+			ms_warning("Could not parse %s",identity);
 			osip_from_free(url);
 			return;
 		}
+		osip_from_free(url);
 	} else err=-2;
 	if (obj->reg_identity!=NULL) {
-		g_free(obj->reg_identity);
+		ms_free(obj->reg_identity);
 		obj->reg_identity=NULL;
 	}
 	if (err==-2) obj->reg_identity=NULL;
-	else obj->reg_identity=g_strdup(identity);
-	
+	else obj->reg_identity=ms_strdup(identity);
 }
 
-void linphone_proxy_config_set_route(LinphoneProxyConfig *obj, const gchar *route)
+void linphone_proxy_config_set_route(LinphoneProxyConfig *obj, const char *route)
 {
 	int err;
 	osip_uri_param_t *lr_param=NULL;
@@ -106,12 +107,12 @@ void linphone_proxy_config_set_route(LinphoneProxyConfig *obj, const gchar *rout
 		osip_route_init(&rt);
 		err=osip_route_parse(rt,route);
 		if (err<0){
-			g_warning("Could not parse %s",route);
+			ms_warning("Could not parse %s",route);
 			osip_route_free(rt);
 			return ;
 		}
 		if (obj->reg_route!=NULL) {
-			g_free(obj->reg_route);
+			ms_free(obj->reg_route);
 			obj->reg_route=NULL;
 		}
 			
@@ -120,25 +121,25 @@ void linphone_proxy_config_set_route(LinphoneProxyConfig *obj, const gchar *rout
 	  	if (lr_param==NULL){
 			osip_uri_uparam_add(rt->url,osip_strdup("lr"),NULL);
 			osip_route_to_str(rt,&tmproute);
-			obj->reg_route=g_strdup(tmproute);
+			obj->reg_route=ms_strdup(tmproute);
 			osip_free(tmproute);
-		}else obj->reg_route=g_strdup(route);
+		}else obj->reg_route=ms_strdup(route);
 	}else{
-		if (obj->reg_route!=NULL) g_free(obj->reg_route);
+		if (obj->reg_route!=NULL) ms_free(obj->reg_route);
 		obj->reg_route=NULL;
 	}
 }
 
-void linphone_proxy_config_enableregister(LinphoneProxyConfig *obj, gboolean val){
+void linphone_proxy_config_enableregister(LinphoneProxyConfig *obj, bool_t val){
 	obj->reg_sendregister=val;
 }
 
-void linphone_proxy_config_expires(LinphoneProxyConfig *obj, gint val){
+void linphone_proxy_config_expires(LinphoneProxyConfig *obj, int val){
 	if (val<=0) val=600;
 	obj->expires=val;
 }
 
-void linphone_proxy_config_enable_publish(LinphoneProxyConfig *obj, gboolean val){
+void linphone_proxy_config_enable_publish(LinphoneProxyConfig *obj, bool_t val){
 	obj->publish=val;
 }
 
@@ -167,41 +168,43 @@ void linphone_proxy_config_apply(LinphoneProxyConfig *obj,LinphoneCore *lc)
 
 void linphone_proxy_config_done(LinphoneProxyConfig *obj)
 {
-	const gchar *id_str;
+	const char *id_str;
 	if (obj->reg_identity!=NULL) id_str=obj->reg_identity;
 	else id_str=linphone_core_get_primary_contact(obj->lc);
 	obj->frozen=FALSE;
 	if (obj->reg_sendregister){
-		gchar *ct=NULL;
-		if (obj->lc->net_conf.use_nat && (obj->lc->net_conf.nat_address!=NULL)) {
+		char *ct=NULL;
+		{
+			char localip[LINPHONE_IPADDR_SIZE];
+			linphone_core_get_local_ip(obj->lc,NULL,localip);
 			osip_from_t *identity;
 			osip_from_init(&identity);
 			osip_from_parse(identity,id_str);
 			osip_free(identity->url->host);
-			identity->url->host=osip_strdup(obj->lc->net_conf.nat_address);
+			identity->url->host=osip_strdup(localip);
 			identity->url->port=osip_malloc(15);
 			snprintf(identity->url->port, 15, "%i", obj->lc->sip_conf.sip_port);
 			osip_from_to_str(identity,&ct);
 			osip_from_free(identity);
 		}
-		obj->rid=eXosip_register_init((gchar*)id_str,obj->reg_proxy,ct,obj->reg_route);
+		obj->rid=eXosip_register_init((char*)id_str,obj->reg_proxy,ct,obj->reg_route);
 		linphone_proxy_config_register(obj);
-		if (ct!=NULL) g_free(ct);
+		if (ct!=NULL) osip_free(ct);
 	}
 }
 
 void linphone_proxy_config_set_realm(LinphoneProxyConfig *cfg, const char *realm)
 {
 	if (cfg->realm!=NULL) {
-		g_free(cfg->realm);
+		ms_free(cfg->realm);
 		cfg->realm=NULL;
 	}
-	if (realm!=NULL) cfg->realm=g_strdup(realm);
+	if (realm!=NULL) cfg->realm=ms_strdup(realm);
 }
 
 void linphone_core_update_proxy_register(LinphoneCore *lc){
-	GList *elem;
-	for(elem=linphone_core_get_proxy_config_list(lc);elem!=NULL;elem=g_list_next(elem)){
+	MSList *elem;
+	for(elem=linphone_core_get_proxy_config_list(lc);elem!=NULL;elem=ms_list_next(elem)){
 		LinphoneProxyConfig *cfg=(LinphoneProxyConfig*) elem->data;
 		if (cfg->reg_sendregister && cfg->rid>=0){
 			if ( (time(NULL)-cfg->reg_time) > cfg->expires){
@@ -222,7 +225,7 @@ int linphone_proxy_config_send_publish(LinphoneProxyConfig *proxy,
 {
   osip_message_t *pub;
   int i;
-  const gchar *from=NULL;
+  const char *from=NULL;
   char buf[5000];
 
   if (proxy->publish==FALSE) return 0;
@@ -368,7 +371,7 @@ entity=\"%s\">\n%s",
 
   if (i<0)
     {
-      g_message("Failed to build publish request.");
+      ms_message("Failed to build publish request.");
       return -1;
     }
 
@@ -378,31 +381,31 @@ entity=\"%s\">\n%s",
   eXosip_unlock();
   if (i<0)
     {
-      g_message("Failed to send publish request.");
+      ms_message("Failed to send publish request.");
       return -1;
     }
   return 0;
 }
 
 void linphone_core_add_proxy_config(LinphoneCore *lc, LinphoneProxyConfig *cfg){
-	lc->sip_conf.proxies=g_list_append(lc->sip_conf.proxies,(gpointer)cfg);
+	lc->sip_conf.proxies=ms_list_append(lc->sip_conf.proxies,(void *)cfg);
 	linphone_proxy_config_apply(cfg,lc);
 }
 
 extern void linphone_friend_check_for_removed_proxy(LinphoneFriend *lf, LinphoneProxyConfig *cfg);
 
 void linphone_core_remove_proxy_config(LinphoneCore *lc, LinphoneProxyConfig *cfg){
-	GList *elem;
-	lc->sip_conf.proxies=g_list_remove(lc->sip_conf.proxies,(gpointer)cfg);
+	MSList *elem;
+	lc->sip_conf.proxies=ms_list_remove(lc->sip_conf.proxies,(void *)cfg);
 	/* add to the list of destroyed proxies, so that the possible unREGISTER request can succeed authentication */
-	lc->sip_conf.deleted_proxies=g_list_append(lc->sip_conf.deleted_proxies,(gpointer)cfg);
+	lc->sip_conf.deleted_proxies=ms_list_append(lc->sip_conf.deleted_proxies,(void *)cfg);
 	/* this will unREGISTER */
 	linphone_proxy_config_edit(cfg);
 	if (lc->default_proxy==cfg){
 		lc->default_proxy=NULL;
 	}
 	/* invalidate all references to this proxy in our friend list */
-	for (elem=lc->friends;elem!=NULL;elem=g_list_next(elem)){
+	for (elem=lc->friends;elem!=NULL;elem=ms_list_next(elem)){
 		linphone_friend_check_for_removed_proxy((LinphoneFriend*)elem->data,cfg);
 	}
 	
@@ -411,8 +414,8 @@ void linphone_core_remove_proxy_config(LinphoneCore *lc, LinphoneProxyConfig *cf
 void linphone_core_set_default_proxy(LinphoneCore *lc, LinphoneProxyConfig *config){
 	/* check if this proxy is in our list */
 	if (config!=NULL){
-		if (g_list_find(lc->sip_conf.proxies,(gconstpointer)config)==NULL){
-			g_warning("Bad proxy address: it is not in the list !");
+		if (ms_list_find(lc->sip_conf.proxies,config)==NULL){
+			ms_warning("Bad proxy address: it is not in the list !");
 			lc->default_proxy=NULL;
 			return ;
 		}
@@ -424,55 +427,57 @@ void linphone_core_set_default_proxy(LinphoneCore *lc, LinphoneProxyConfig *conf
 
 void linphone_core_set_default_proxy_index(LinphoneCore *lc, int index){
 	if (index<0) linphone_core_set_default_proxy(lc,NULL);
-	else linphone_core_set_default_proxy(lc,g_list_nth_data(lc->sip_conf.proxies,index));
+	else linphone_core_set_default_proxy(lc,ms_list_nth_data(lc->sip_conf.proxies,index));
 }
 
 int linphone_core_get_default_proxy(LinphoneCore *lc, LinphoneProxyConfig **config){
 	int pos=-1;
 	if (config!=NULL) *config=lc->default_proxy;
 	if (lc->default_proxy!=NULL){
-		pos=g_list_position(lc->sip_conf.proxies,g_list_find(lc->sip_conf.proxies,(gpointer)lc->default_proxy));
+		pos=ms_list_position(lc->sip_conf.proxies,ms_list_find(lc->sip_conf.proxies,(void *)lc->default_proxy));
 	}
 	return pos;
 }
 
-static gint rid_compare(LinphoneProxyConfig *cfg,int rid){
-	g_message("cfg= %s, cfg->rid=%i, rid=%i",cfg->reg_proxy, cfg->rid, rid);
-	return cfg->rid-rid;
+static int rid_compare(const void *pcfg,const void *prid){
+	const LinphoneProxyConfig *cfg=(const LinphoneProxyConfig*)pcfg;
+	const int *rid=(const int*)prid;
+	ms_message("cfg= %s, cfg->rid=%i, rid=%i",cfg->reg_proxy, cfg->rid, *rid);
+	return cfg->rid-(*rid);
 }
 
 LinphoneProxyConfig *linphone_core_get_proxy_config_from_rid(LinphoneCore *lc, int rid){
-	GList *elem=g_list_find_custom(lc->sip_conf.proxies,GINT_TO_POINTER(rid),(GCompareFunc)rid_compare);
+	MSList *elem=ms_list_find_custom(lc->sip_conf.proxies,rid_compare, &rid);
 	if (elem==NULL){
-		g_message("linphone_core_get_proxy_config_from_rid: searching in deleted proxies...");
-		elem=g_list_find_custom(lc->sip_conf.deleted_proxies,GINT_TO_POINTER(rid),(GCompareFunc)rid_compare);
+		ms_message("linphone_core_get_proxy_config_from_rid: searching in deleted proxies...");
+		elem=ms_list_find_custom(lc->sip_conf.deleted_proxies,rid_compare, &rid);
 	}
 	if (elem==NULL) return NULL;
 	else return (LinphoneProxyConfig*)elem->data;
 }
 
-void linphone_core_retry_proxy_register(LinphoneCore *lc, const gchar *realm)
+void linphone_core_retry_proxy_register(LinphoneCore *lc, const char *realm)
 {
-	GList *elem;
-	for (elem=lc->sip_conf.proxies;elem!=NULL;elem=g_list_next(elem)){
+	MSList *elem;
+	for (elem=lc->sip_conf.proxies;elem!=NULL;elem=ms_list_next(elem)){
 		LinphoneProxyConfig *cfg=(LinphoneProxyConfig*)elem->data;
-		/*g_message("linphone_core_retry_proxy_register: cfg->auth_pending=%i, cfg->realm=%s, realm=%s",
+		/*ms_message("linphone_core_retry_proxy_register: cfg->auth_pending=%i, cfg->realm=%s, realm=%s",
 					cfg->auth_pending,cfg->realm,realm);*/
 		if (cfg->auth_pending && cfg->realm!=NULL && strcmp(cfg->realm,realm)==0){
-			g_message("Restarting REGISTER request for %s.",cfg->reg_proxy);
+			ms_message("Restarting REGISTER request for %s.",cfg->reg_proxy);
 			linphone_proxy_config_register(cfg);
 		}
 	}
 }
 
-GList *linphone_core_get_proxy_config_list(LinphoneCore *lc){
+MSList *linphone_core_get_proxy_config_list(LinphoneCore *lc){
 	return lc->sip_conf.proxies;
 }
 
 
 void linphone_proxy_config_write_to_config_file(LpConfig *config, LinphoneProxyConfig *obj, int index)
 {
-	gchar key[50];
+	char key[50];
 
 	sprintf(key,"proxy_%i",index);
 	if (obj==NULL){
@@ -495,9 +500,9 @@ void linphone_proxy_config_write_to_config_file(LpConfig *config, LinphoneProxyC
 
 LinphoneProxyConfig *linphone_proxy_config_new_from_config_file(LpConfig *config, int index)
 {
-	const gchar *tmp;
+	const char *tmp;
 	LinphoneProxyConfig *cfg;
-	gchar key[50];
+	char key[50];
 	
 	sprintf(key,"proxy_%i",index);
 
