@@ -31,6 +31,9 @@ extern eXosip_t eXosip;
 
 /* You need the Platform SDK to compile this. */
 #include <Windows.h>
+
+#if 0
+
 #include <Iphlpapi.h>
 
 int
@@ -202,6 +205,15 @@ eXosip_guess_ip_for_via (int family, char *address, int size)
 	return -1;
 }
 
+#endif /*if 0*/
+
+int
+eXosip_guess_ip_for_via (int family, char *address, int size){
+	char *res=NULL;
+	eXosip_get_localip_for("15.128.128.93",&res);
+	strncpy(address,res,size);
+	return 0;
+}
 
 #else /* sun, *BSD, linux, and other? */
 
@@ -345,10 +357,32 @@ ppl_dns_default_gateway_ipv6 (char *address, int size)
   return 0;
 }
 
+
+#endif
+
+#ifdef SM
+
+void eXosip_get_localip_from_via(osip_message_t *mesg,char **locip){
+	osip_via_t *via=NULL;
+	char *host;
+	via=(osip_via_t*)osip_list_get(mesg->vias,0);
+	if (via==NULL) {
+		host="15.128.128.93";
+		eXosip_trace(OSIP_ERROR,("Could not get via:%s"));
+	}else host=via->host;
+	eXosip_get_localip_for(host,locip);
+	
+}
+#endif
+
+#ifndef MAXHOSTNAMELEN
+#define MAXHOSTNAMELEN 1024
+#endif
+
 void eXosip_get_localip_for(char *address_to_reach,char **loc){
 	int err,tmp;
 	struct addrinfo hints;
-	struct addrinfo *res=NULL;
+	struct addrinfo *res=NULL,*res0=NULL;
 	struct sockaddr_storage addr;
 	int sock;
 #ifdef __APPLE_CC__
@@ -371,32 +405,39 @@ void eXosip_get_localip_for(char *address_to_reach,char **loc){
 	hints.ai_family=(eXosip.ip_family==AF_INET) ? PF_INET:PF_INET6;
 	hints.ai_socktype=SOCK_DGRAM;
 	/*hints.ai_flags=AI_NUMERICHOST|AI_CANONNAME;*/
-	err=getaddrinfo(address_to_reach,"5060",&hints,&res);
+	err=getaddrinfo(address_to_reach,"5060",&hints,&res0);
 	if (err!=0){
 		eXosip_trace(OSIP_ERROR,("Error in getaddrinfo for %s: %s\n",address_to_reach,gai_strerror(err)));
 		return ;
 	}
-	if (res==NULL){
+	if (res0==NULL){
 		eXosip_trace(OSIP_ERROR,("getaddrinfo reported nothing !"));
 		abort();
 		return ;
 	}
-	sock=socket(res->ai_family,SOCK_DGRAM,0);
-	tmp=1;
-	err=setsockopt(sock,SOL_SOCKET,SO_REUSEADDR,&tmp,sizeof(int));
-	if (err<0){
-		eXosip_trace(OSIP_ERROR,("Error in setsockopt: %s\n",strerror(errno)));
-		abort();
-		return ;
+	for (res=res0;res!=NULL;res=res->ai_next){
+		sock=socket(res->ai_family,SOCK_DGRAM,0);
+		tmp=1;
+		err=setsockopt(sock,SOL_SOCKET,SO_REUSEADDR,(char*)&tmp,sizeof(int));
+		if (err<0){
+			eXosip_trace(OSIP_ERROR,("Error in setsockopt: %s\n",strerror(errno)));
+			abort();
+			return ;
+		}
+		err=connect(sock,res->ai_addr,res->ai_addrlen);
+		if (err<0) {
+			eXosip_trace(OSIP_ERROR,("Error in connect: %s\n",strerror(errno)));
+ 			close(sock);
+			sock=-1;
+			continue;
+		}else break;
 	}
-	err=connect(sock,res->ai_addr,res->ai_addrlen);
-	if (err<0) {
-		eXosip_trace(OSIP_ERROR,("Error in connect: %s\n",strerror(errno)));
- 		freeaddrinfo(res);
- 		close(sock);
-		return ;
+	freeaddrinfo(res0);
+	if (sock==-1){
+		eXosip_trace(OSIP_WARNING,("Could not find interface to reach %s\n",address_to_reach));
+		return;
 	}
-	freeaddrinfo(res);
+	res0=NULL;
 	res=NULL;
 	s=sizeof(addr);
 	err=getsockname(sock,(struct sockaddr*)&addr,&s);
@@ -408,7 +449,7 @@ void eXosip_get_localip_for(char *address_to_reach,char **loc){
 	
 	err=getnameinfo((struct sockaddr *)&addr,s,*loc,MAXHOSTNAMELEN,NULL,0,NI_NUMERICHOST);
 	if (err!=0){
-		eXosip_trace(OSIP_ERROR,("getnameinfo error:%s",strerror(errno)));
+		eXosip_trace(OSIP_ERROR,("getnameinfo error:%s ; while finding local address for %s",strerror(errno), address_to_reach));
 		abort();
 		return ;
 	}
@@ -417,23 +458,6 @@ void eXosip_get_localip_for(char *address_to_reach,char **loc){
 	return ;
 }
 
-#endif
-
-#ifdef SM
-
-void eXosip_get_localip_from_via(osip_message_t *mesg,char **locip){
-	osip_via_t *via=NULL;
-	char *host;
-	via=(osip_via_t*)osip_list_get(mesg->vias,0);
-	if (via==NULL) {
-		host="15.128.128.93";
-		eXosip_trace(OSIP_ERROR,("Could not get via:%s"));
-	}else host=via->host;
-	eXosip_get_localip_for(host,locip);
-	
-}
-#endif
-
 char *strdup_printf(const char *fmt, ...)
 {
 	/* Guess we need no more than 100 bytes. */
@@ -504,7 +528,7 @@ eXosip_get_addrinfo (struct addrinfo **addrinfo, char *hostname, int service)
  else
  {
    /* hostname must be resolved */
-   hints.ai_flags = AI_CANONNAME;
+   hints.ai_flags = 0;
    hints.ai_family = (eXosip.ip_family==AF_INET) ? PF_INET:PF_INET6;
    OSIP_TRACE (osip_trace
 	       (__FILE__, __LINE__, OSIP_INFO2, NULL,
