@@ -673,3 +673,23 @@ on_addressentry_destroy                (GtkObject       *object,
 {
 	linphone_gnome_save_uri_history(get_uiobj());
 }
+
+void
+on_video_enabled_toggled               (GtkToggleButton *togglebutton,
+                                        gpointer         user_data)
+{
+	linphone_core_enable_video(get_core(),gtk_toggle_button_get_active(togglebutton));
+}
+
+
+void
+on_echocancelation_toggled             (GtkToggleButton *togglebutton,
+                                        gpointer         user_data)
+{
+	linphone_core_enable_echo_cancelation(get_core(),
+		gtk_toggle_button_get_active(togglebutton));
+}
+
+
+
+
