@@ -101,6 +101,9 @@ void main_window_create(LinphoneGnomeUI *obj)
 	child=lookup_widget(window,"showmore");
 	/* hide the optionnal controls at startup */
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(child),0);
+#ifndef VIDEO_ENABLED
+	gtk_widget_hide(lookup_widget(child,"video_enabled"));
+#endif
 	presence_box_init(&obj->main_window.presencebox,window,obj->core);
 	friend_list_init(&obj->main_window.friendlist,obj->core,window);
 	g_object_set_data(G_OBJECT(window),"ui",(gpointer)obj);
@@ -170,7 +173,7 @@ void linphone_gnome_ui_display_something(LinphoneGnomeUI *ui,GtkMessageType type
 }
 
 /* these are the LinphoneCore virtual functions */
-void linphone_gnome_display_message(LinphoneCore *lc,char *message)
+void linphone_gnome_display_message(LinphoneCore *lc, const char *message)
 {
 	LinphoneGnomeUI *ui=(LinphoneGnomeUI*)lc->data;
 	linphone_gnome_ui_display_something(ui,GTK_MESSAGE_INFO,message);
@@ -178,7 +181,7 @@ void linphone_gnome_display_message(LinphoneCore *lc,char *message)
 
 #ifdef VINCENT_MAURY_RSVP
 /* Question box with yes/no answer. */
-void linphone_gnome_display_yes_no(LinphoneCore *lc,char *message)
+void linphone_gnome_display_yes_no(LinphoneCore *lc,const char *message)
 {
 	LinphoneGnomeUI *ui=(LinphoneGnomeUI*)lc->data;
 	if (strcmp(message,"With QoS")==0)
@@ -193,13 +196,13 @@ void linphone_gnome_display_yes_no(LinphoneCore *lc,char *message)
 }
 #endif
 
-void linphone_gnome_display_warning(LinphoneCore *lc,char *warning)
+void linphone_gnome_display_warning(LinphoneCore *lc, const char *warning)
 {
 	LinphoneGnomeUI *ui=(LinphoneGnomeUI*)lc->data;
 	linphone_gnome_ui_display_something(ui,GTK_MESSAGE_WARNING,warning);
 }
 
-void linphone_gnome_display_status(LinphoneCore *lc,char *status)
+void linphone_gnome_display_status(LinphoneCore *lc, const char *status)
 {
 	LinphoneGnomeUI *ui=(LinphoneGnomeUI*)lc->data;
 	if (ui->main_window.window==NULL) return;
@@ -225,12 +228,10 @@ void linphone_gnome_show(LinphoneCore *lc)
 	linphone_gnome_ui_show(ui);
 }
 
-void linphone_gnome_display_url(LinphoneCore *lc, char *message, char *url)
+void linphone_gnome_display_url(LinphoneCore *lc, const char *message, const char *url)
 {
 	LinphoneGnomeUI *ui=(LinphoneGnomeUI*)lc->data;
-	if (!linphone_core_is_in_main_thread(ui->core)) gdk_threads_enter();
 	alt_ressource_display(ui,url);
-	if (!linphone_core_is_in_main_thread(ui->core)) gdk_threads_leave();
 }
 
 
@@ -316,7 +317,7 @@ void proxy_changed(GtkWidget *combo){
 void linphone_refresh_proxy_combo_box(GtkWidget *window){
 	LinphoneCore *lc=get_core();
 	GtkWidget *combo;
-	GList *elem=linphone_core_get_proxy_config_list(lc);
+	MSList *elem=linphone_core_get_proxy_config_list(lc);
 	LinphoneProxyConfig *cfg=NULL;
 	GtkWidget *hbox=lookup_widget(window,"proxy_hbox");
 	
@@ -364,7 +365,7 @@ void linphone_gnome_uninit(LinphoneGnomeUI *ui)
 
 GtkWidget *proxy_combo_box_new(LinphoneProxyConfig *selected){
 	GtkWidget *combo;
-	GList *elem;
+	MSList *elem;
 	GtkListStore *store=gtk_list_store_new(2,G_TYPE_STRING,G_TYPE_POINTER);
 	GtkTreeIter iter;
 	GtkTreeIter prxiter;
@@ -374,7 +375,7 @@ GtkWidget *proxy_combo_box_new(LinphoneProxyConfig *selected){
 	elem=linphone_core_get_proxy_config_list(get_core());
 	gtk_list_store_append(store,&iter);
 	gtk_list_store_set(store,&iter,0,_("None"),1,(gpointer)NULL,-1);
-	for(;elem!=NULL;elem=g_list_next(elem)){
+	for(;elem!=NULL;elem=ms_list_next(elem)){
 		LinphoneProxyConfig *proxy=(LinphoneProxyConfig*)elem->data;
 		gtk_list_store_append(store,&iter);
 		gtk_list_store_set(store,&iter,0,proxy->reg_proxy,1,(gpointer)proxy,-1);
@@ -415,7 +416,7 @@ void linphone_gnome_update_call_logs(LinphoneGnomeUI *ui){
 	GtkTextBuffer *tb;
 	GtkTextIter begin,end;
 	GtkTextTag *tag;
-	GList *elem;
+	MSList *elem;
 	if (ui->logs==NULL) return;
 	tv=GTK_TEXT_VIEW(lookup_widget(ui->logs,"logview"));
 	tb=gtk_text_view_get_buffer(tv);
@@ -423,7 +424,7 @@ void linphone_gnome_update_call_logs(LinphoneGnomeUI *ui){
 	gtk_text_buffer_get_bounds(tb,&begin,&end);
 	gtk_text_buffer_delete(tb,&begin,&end);
 	gtk_text_buffer_get_end_iter(tb,&end);
-	for (elem=linphone_core_get_call_logs(lc);elem!=NULL;elem=g_list_next(elem)){
+	for (elem=linphone_core_get_call_logs(lc);elem!=NULL;elem=ms_list_next(elem)){
 		LinphoneCallLog *cl=(LinphoneCallLog*)elem->data;
 		gchar *str=linphone_call_log_to_str(cl);
 		tag=NULL;
@@ -435,7 +436,7 @@ void linphone_gnome_update_call_logs(LinphoneGnomeUI *ui){
 		gtk_text_buffer_insert_with_tags(tb,&end,str,-1,tag,NULL);
 		gtk_text_buffer_insert(tb,&end,"\n",-1);
 		
-		g_free(str);
+		ms_free(str);
 	}
 }
 
