@@ -42,6 +42,18 @@ enum {
 #define property_box_changed() 	gnome_property_box_changed(GNOME_PROPERTY_BOX ( (&uiobj->propbox)->prop))
 #define get_main_window() (&uiobj->main_window)
 
+#if !GTK_CHECK_VERSION(2,6,0)
+static gchar * _lp_combo_box_get_active_text (GtkComboBox *combobox)
+{
+	GtkTreeIter iter;
+	GtkTreeModel *model;
+	gchar *text = NULL;
+	model = gtk_combo_box_get_model (combobox);
+	if (gtk_combo_box_get_active_iter (combobox, &iter) && model)
+		gtk_tree_model_get (model, &iter, 0, &text, -1);
+	return text;
+}
+#endif /* GTK+ < 2.6.0 */
 
 void net_section_init(NetSection *sec, GtkWidget *prop)
 {
@@ -50,48 +62,13 @@ void net_section_init(NetSection *sec, GtkWidget *prop)
 #ifdef LINPHONE_DEPRECATED
 	sec->interfaces=lookup_widget(prop, "interfaces");	
 #endif
-	sec->enable_nat=lookup_widget(prop,"enable_nat");
 	sec->nat_address=lookup_widget(prop,"nat_address");
-	sec->nat_label=lookup_widget(prop,"nat_label");
 	sec->use_sipinfo=lookup_widget(prop,"use_sipinfo");
 	sec->enable_ipv6=lookup_widget(prop,"enable_ipv6");
 }
 
-void codec_list_update(GtkTreeView *listview,double bandwidth);
+void codec_list_update(GtkTreeView *listview);
 
-void on_connection_type_selected(CodecSection *sec, gint type)
-{
-	/* we must call linphone_core so that codec usability is checked */
-	linphone_core_set_connection_type(get_core(),type);
-	codec_list_update(GTK_TREE_VIEW(sec->au_codec_list),bandwidths[type]);
-	sec->type_sel=type;
-	property_box_changed();
-}
-
-void on_28k_selected(GtkMenuItem *menuitem, gpointer user_data)
-{
-	on_connection_type_selected((CodecSection*)user_data , 0);
-}
-
-void on_56k_selected(GtkMenuItem *menuitem, gpointer user_data)
-{
-	on_connection_type_selected((CodecSection*)user_data , 1);
-}
-
-void on_128k_selected(GtkMenuItem *menuitem, gpointer user_data)
-{
-	on_connection_type_selected((CodecSection*)user_data , 2);
-}
-
-void on_adsl_selected(GtkMenuItem *menuitem, gpointer user_data)
-{
-	on_connection_type_selected((CodecSection*)user_data , 3);
-}
-
-void on_ethernet_selected(GtkMenuItem *menuitem, gpointer user_data)
-{
-	on_connection_type_selected((CodecSection*)user_data , 4);
-}
 
 void net_selection_changed_cb(GtkTreeSelection *select, gpointer userdata)
 {
@@ -101,8 +78,8 @@ void net_selection_changed_cb(GtkTreeSelection *select, gpointer userdata)
 void net_section_fill(NetSection *sec,LinphoneCore *lc)
 {
 	gfloat value;
-	gboolean use_nat;
-	const gchar *nat_address;
+	bool_t use_nat;
+	const gchar *nat_address,*stun_server;
 	
 	value=(gfloat)linphone_core_get_audio_jittcomp(lc);
 	/* put the current value of jitt_comp*/
@@ -110,62 +87,30 @@ void net_section_fill(NetSection *sec,LinphoneCore *lc)
 	/* display current rtp port */
   	gtk_spin_button_set_value(GTK_SPIN_BUTTON(sec->au_port),
 						(gfloat)linphone_core_get_audio_port(lc));
-	
-#ifdef LINPHONE_DEPRECATED
-	store= gtk_list_store_new (IFACE_NCOLUMNS, G_TYPE_INT, G_TYPE_STRING,G_TYPE_STRING);
-	/* draw the list of interface */
-	elem=linphone_core_get_net_interfaces(lc);
-	while(elem!=NULL){
-		interface_t *iface=(interface_t *)elem->data;
-		/* get an iterator */
-		gtk_list_store_append(store,&iter);
-		if (iface==linphone_core_get_selected_interface(lc)){
-			selected=iter;
-		}
-#ifdef INET6
-		gtk_list_store_set(store,&iter, IFACE_INDEX, iface->index, IFACE_NAME,iface->name,IFACE_ADDR,iface->ipaddr,-1);
-#else
-		gtk_list_store_set(store,&iter,IFACE_NAME,iface->name,IFACE_ADDR,iface->ip4addr,-1);
-#endif
-		elem=g_list_next(elem);
-	}
-	gtk_tree_view_set_model(GTK_TREE_VIEW(sec->interfaces),GTK_TREE_MODEL(store));
-	g_object_unref(G_OBJECT(store));
-	renderer = gtk_cell_renderer_text_new ();
-#ifdef INET6
-	column = gtk_tree_view_column_new_with_attributes (_("Index"),
-                                                   renderer,
-                                                   "text", IFACE_INDEX,
-                                                   NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (sec->interfaces), column);
-#endif
-	column = gtk_tree_view_column_new_with_attributes (_("Name"),
-                                                   renderer,
-                                                   "text", IFACE_NAME,
-                                                   NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (sec->interfaces), column);
-	column = gtk_tree_view_column_new_with_attributes (_("Address"),
-                                                   renderer,
-                                                   "text", IFACE_ADDR,
-                                                   NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (sec->interfaces), column);
-	/* Setup the selection handler */
-	select = gtk_tree_view_get_selection (GTK_TREE_VIEW (sec->interfaces));
-	gtk_tree_selection_set_mode (select, GTK_SELECTION_SINGLE);
-	gtk_tree_selection_select_iter(select,&selected);
-	g_signal_connect (G_OBJECT (select), "changed",
-                  G_CALLBACK (net_selection_changed_cb),
-                  NULL);
-	gtk_tree_view_columns_autosize(GTK_TREE_VIEW (sec->interfaces));
-#endif
+
 	
 	/* nat setup */
-	nat_address=linphone_core_get_nat_address(lc,&use_nat);
+	nat_address=linphone_core_get_nat_address(lc);
+	use_nat=linphone_core_nat_address_used(lc);
+	
+	if (use_nat)
+		gtk_toggle_button_set_active(
+			GTK_TOGGLE_BUTTON(lookup_widget(get_property_box()->prop,"static_nat"))
+				,use_nat);
 	
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(sec->enable_nat),use_nat);
 	if (nat_address!=NULL) {
 		gtk_entry_set_text(GTK_ENTRY(sec->nat_address),nat_address);
 	}
+	stun_server=linphone_core_get_stun_server(lc);
+	if (stun_server!=NULL)
+		gtk_entry_set_text(
+		GTK_ENTRY(lookup_widget(get_property_box()->prop,"stun_server")),
+		stun_server);
+	if (!use_nat)
+		gtk_toggle_button_set_active(
+			GTK_TOGGLE_BUTTON(lookup_widget(get_property_box()->prop,"use_stun")),
+			linphone_core_stun_enabled(lc));
+
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(sec->use_sipinfo),
 		linphone_core_get_use_info_for_dtmf(lc));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(sec->enable_ipv6),
@@ -180,8 +125,7 @@ on_enable_nat_toggled                  (GtkToggleButton *togglebutton,
 	NetSection *sec=&prop->net;
 	gboolean use_nat;
 	use_nat=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sec->enable_nat));
-	gtk_widget_set_sensitive(sec->nat_label,use_nat);
-	gtk_widget_set_sensitive(sec->nat_address,use_nat);
+	linphone_core_use_nat_address(get_core(),use_nat);
 	property_box_changed();
 	
 }
@@ -205,31 +149,23 @@ on_enable_ipv6_toggled                 (GtkToggleButton *togglebutton,
 
 void net_section_apply(NetSection *sec,LinphoneCore *lc)
 {
-	gboolean use_nat;
+	gboolean use_nat,use_stun;
 	gchar *name;
-#ifdef LINPHONE_DEPRECATED
-#ifdef INET6
- 	gint index;  	
-#endif
-	/* get network interface*/
-	select = gtk_tree_view_get_selection (GTK_TREE_VIEW (sec->interfaces));
-	if (gtk_tree_selection_get_selected (select, &model, &iter))
-	{
-#ifdef INET6
- 		gtk_tree_model_get (model, &iter, IFACE_INDEX , &index, -1);
- 		linphone_core_select_net_interface(lc,index);
-#else
-		gtk_tree_model_get (model, &iter,IFACE_NAME , &name, -1);
-		linphone_core_select_net_interface(lc,name);
-		g_free(name);
-#endif
-	}
-	linphone_core_set_connection_type(lc,sec->type_sel);
-#endif
 	
-	use_nat=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sec->enable_nat));
+	use_nat=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(
+			lookup_widget(get_property_box()->prop,"static_nat")));
 	name=gtk_editable_get_chars(GTK_EDITABLE(sec->nat_address),0,-1);
-	linphone_core_set_nat_address(lc,name,use_nat);
+	linphone_core_set_nat_address(lc,name);
+	linphone_core_use_nat_address(lc,use_nat);
+	g_free(name);
+
+	use_stun=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(
+			lookup_widget(get_property_box()->prop,"use_stun") ));
+	name=gtk_editable_get_chars(GTK_EDITABLE(
+			lookup_widget(get_property_box()->prop,"stun_server") ),0,-1);
+	linphone_core_set_stun_server(lc,name);
+	g_free(name);
+	linphone_core_enable_stun(lc,use_stun);
 	
 	{
 	/* get the value of jitt_comp*/
@@ -244,7 +180,7 @@ void net_section_apply(NetSection *sec,LinphoneCore *lc)
 
 
 enum{
-	PROXY_CONFIG_SERVER,
+	PROXY_CONFIG_IDENTITY,
 	PROXY_CONFIG_REF,
 	PROXY_CONFIG_NCOL
 };
@@ -267,9 +203,9 @@ void sip_section_init(SipSection *sec,GtkWidget *prop)
 	gtk_tree_view_set_model(GTK_TREE_VIEW(sec->proxy_list),GTK_TREE_MODEL(store));
 	g_object_unref(G_OBJECT(store));
 	renderer = gtk_cell_renderer_text_new ();
-	column = gtk_tree_view_column_new_with_attributes (_("Server address"),
+	column = gtk_tree_view_column_new_with_attributes (_("Account"),
                                                    renderer,
-                                                   "text", PROXY_CONFIG_SERVER,
+                                                   "text", PROXY_CONFIG_IDENTITY,
                                                    NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (sec->proxy_list), column);
 	
@@ -279,15 +215,15 @@ void sip_section_init(SipSection *sec,GtkWidget *prop)
 
 
 void proxy_list_fill(GtkTreeModel *model, LinphoneCore *lc){
-	GList *elem;
+	MSList *elem;
 	GtkTreeIter iter;
 	/* fill the proxy list */
 	gtk_list_store_clear(GTK_LIST_STORE(model));
 	elem=linphone_core_get_proxy_config_list(lc);
-	for(;elem!=NULL;elem=g_list_next(elem)){
+	for(;elem!=NULL;elem=ms_list_next(elem)){
 		LinphoneProxyConfig *pcfg=(LinphoneProxyConfig*)elem->data;
 		gtk_list_store_append(GTK_LIST_STORE(model),&iter);
-		gtk_list_store_set(GTK_LIST_STORE(model),&iter,PROXY_CONFIG_SERVER,pcfg->reg_proxy,
+		gtk_list_store_set(GTK_LIST_STORE(model),&iter,PROXY_CONFIG_IDENTITY,pcfg->reg_identity,
 			PROXY_CONFIG_REF,pcfg,-1);
 	}
 }
@@ -460,7 +396,6 @@ void codec_section_init(CodecSection *sec, GtkWidget *prop)
 {
 	sec->au_codec_list=lookup_widget(prop,"au_codec_list");
 	sec->codec_info=lookup_widget(prop,"codec_info");
-	sec->connection_type=lookup_widget(prop,"connection_type");
 }
 
 void codec_selection_changed_cb(GtkTreeSelection *selection, gpointer data)
@@ -479,12 +414,12 @@ void codec_selection_changed_cb(GtkTreeSelection *selection, gpointer data)
 	}
 }
 
-void codec_list_build(GtkTreeView *listview,GList *codeclist)
+void codec_list_build(GtkTreeView *listview,const MSList *codeclist)
 {
-	GList *elem=codeclist;
+	const MSList *elem;
 	GtkListStore *store = gtk_list_store_new (CODEC_NCOLUMNS, G_TYPE_STRING,
-																G_TYPE_STRING,
-																G_TYPE_STRING,
+																G_TYPE_INT,
+																G_TYPE_FLOAT,
 																G_TYPE_STRING,
 																G_TYPE_POINTER,
 																G_TYPE_STRING);
@@ -492,19 +427,20 @@ void codec_list_build(GtkTreeView *listview,GList *codeclist)
 	GtkCellRenderer *renderer;
 	GtkTreeViewColumn *column;
 	GtkTreeSelection *select=gtk_tree_view_get_selection (listview);
-	while(elem!=NULL){
+	for(elem=codeclist; elem!=NULL; elem=elem->next){
 		gchar *status;
-		gchar *bitrate,*rate;
+		gint rate;
+		gfloat bitrate; 
 		gchar *color;
 		struct _PayloadType *pt=(struct _PayloadType *)elem->data;
 		if (payload_type_enabled(pt)) status=_("Enabled");
 		else status=_("Disabled");
-		if (payload_type_usable(pt)) color="blue";
+		if (linphone_core_check_payload_type_usability(get_core(),pt)) color="blue";
 		else color="red";
 		/* get an iterator */
 		gtk_list_store_append(store,&iter);
-		bitrate=g_strdup_printf("%g",((double)payload_type_get_bitrate(pt))/1000.0);
-		rate=g_strdup_printf("%i",payload_type_get_rate(pt));
+		bitrate=payload_type_get_bitrate(pt)/1000.0;
+		rate=payload_type_get_rate(pt);
 		gtk_list_store_set(store,&iter,	CODEC_NAME,payload_type_get_mime(pt),
 										CODEC_RATE,rate,
 										CODEC_BITRATE,bitrate,
@@ -512,9 +448,6 @@ void codec_list_build(GtkTreeView *listview,GList *codeclist)
 										CODEC_PRIVDATA,(gpointer)pt,
 										CODEC_COLOR,(gpointer)color,
 										-1);
-		g_free(rate);
-		g_free(bitrate);
-		elem=g_list_next(elem);
 	}
 	gtk_tree_view_set_model(listview,GTK_TREE_MODEL(store));
 	g_object_unref(G_OBJECT(store));
@@ -553,52 +486,29 @@ void codec_list_build(GtkTreeView *listview,GList *codeclist)
                   NULL);
 }
 
-void codec_section_fill(CodecSection *sec, LinphoneCore *lc)
+void codec_section_fill(CodecSection *sec, LinphoneCore *lc, GtkWidget *propbox)
 {
-	GtkWidget *optionmenu=sec->connection_type;
-	GtkWidget *menu;
-	GtkItem *menu_item;
-	GtkMenuShell *menushell;
-	GList *item_list,*elem;
 	/* display prefered codecs*/
-	GList *audio_codecs=linphone_core_get_audio_codecs(lc);
+	int value;
+	const MSList *audio_codecs=linphone_core_get_audio_codecs(lc);
 	codec_list_build(GTK_TREE_VIEW(sec->au_codec_list),audio_codecs);
-	g_list_free(audio_codecs);
-	menu=gtk_option_menu_get_menu(GTK_OPTION_MENU(optionmenu));
-	menushell=GTK_MENU_SHELL(menu);
-	elem=item_list=menushell->children;
-	
-	/* 28k menu item*/
-	menu_item=(GtkItem*)(elem->data);
-	gtk_signal_connect(GTK_OBJECT(menu_item),"activate",(GtkSignalFunc)on_28k_selected,(gpointer)sec);
-	elem=g_list_next(elem);
-	/* 56k menu item */
-    menu_item=(GtkItem*)(elem->data);
-	gtk_signal_connect(GTK_OBJECT(menu_item),"activate",(GtkSignalFunc)on_56k_selected,(gpointer)sec);
-	elem=g_list_next(elem);
-	/* 128k menu item */
-	menu_item=(GtkItem*)(elem->data);
-	gtk_signal_connect(GTK_OBJECT(menu_item),"activate",(GtkSignalFunc)on_128k_selected,(gpointer)sec);
-	elem=g_list_next(elem);
-	/* ADSL menu item */
-	menu_item=(GtkItem*)(elem->data);
-	gtk_signal_connect(GTK_OBJECT(menu_item),"activate",(GtkSignalFunc)on_adsl_selected,(gpointer)sec);
-	elem=g_list_next(elem);
-	/* Ethernet menu item */
-	menu_item=(GtkItem*)(elem->data);
-	gtk_signal_connect(GTK_OBJECT(menu_item),"activate",(GtkSignalFunc)on_ethernet_selected,(gpointer)sec);
-	elem=g_list_next(elem);
-	sec->type_sel=linphone_core_get_connection_type(lc);
-	gtk_option_menu_set_history(GTK_OPTION_MENU(optionmenu),sec->type_sel);
-	
-	
+	value=linphone_core_get_download_bandwidth(lc);
+	if (value!=0)
+		gtk_spin_button_set_value(GTK_SPIN_BUTTON(lookup_widget(propbox,"download_bw")),value);
+	else 
+		gtk_entry_set_text(GTK_ENTRY(lookup_widget(propbox,"download_bw")),_("Unlimited"));
+	value=linphone_core_get_upload_bandwidth(lc);
+	if (value!=0)
+		gtk_spin_button_set_value(GTK_SPIN_BUTTON(lookup_widget(propbox,"upload_bw")),value);
+	else 
+		gtk_entry_set_text(GTK_ENTRY(lookup_widget(propbox,"upload_bw")),_("Unlimited"));
 }
 
 void codec_section_apply(CodecSection *sec, LinphoneCore *lc)
 {
 	GtkTreeIter iter;
 	struct _PayloadType *pt;
-	GList *codeclist=NULL;
+	MSList *codeclist=NULL;
 	gchar *status;
 	GtkTreeModel *model=gtk_tree_view_get_model(GTK_TREE_VIEW(sec->au_codec_list));
 	/* retrieve the codec list */
@@ -608,7 +518,7 @@ void codec_section_apply(CodecSection *sec, LinphoneCore *lc)
 		g_return_if_fail(pt!=NULL);
 		if (strcmp(status,_("Enabled"))==0) payload_type_set_enable(pt,1);
 		else payload_type_set_enable(pt,0);
-		codeclist=g_list_append(codeclist,(gpointer)pt);
+		codeclist=ms_list_append(codeclist,pt);
 	}while (gtk_tree_model_iter_next(model,&iter));
 	linphone_core_set_audio_codecs(lc,codeclist);
 }
@@ -624,9 +534,14 @@ void
 on_play_card_changed                   (GtkComboBox     *combobox,
                                         gpointer         user_data)
 {
-	int dev=gtk_combo_box_get_active(combobox);
+#if GTK_CHECK_VERSION(2,6,0)
+	char *dev=gtk_combo_box_get_active_text(combobox);
+#else  /* GTK < 2.6.0 */
+	char *dev=_lp_combo_box_get_active_text(combobox);
+#endif /* GTK < 2.6.0 */
 	linphone_core_set_playback_device(get_core(),dev);
 	property_box_changed();
+	g_free(dev);
 }
 
 
@@ -634,42 +549,59 @@ void
 on_capt_card_changed                   (GtkComboBox     *combobox,
                                         gpointer         user_data)
 {
-	int dev=gtk_combo_box_get_active(combobox);
+#if GTK_CHECK_VERSION(2,6,0)
+	char * dev=gtk_combo_box_get_active_text(combobox);
+#else  /* GTK < 2.6.0 */
+	char * dev=_lp_combo_box_get_active_text(combobox);
+#endif /* GTK < 2.6.0 */
 	linphone_core_set_capture_device(get_core(),dev);
 	property_box_changed();
+	g_free(dev);
 }
 
 void
 on_ring_card_changed                   (GtkComboBox     *combobox,
                                         gpointer         user_data)
 {
-	int dev=gtk_combo_box_get_active(combobox);
+#if GTK_CHECK_VERSION(2,6,0)
+	char * dev=gtk_combo_box_get_active_text(combobox);
+#else  /* GTK < 2.6.0 */
+	char * dev=_lp_combo_box_get_active_text(combobox);
+#endif /* GTK < 2.6.0 */
 	linphone_core_set_ringer_device(get_core(),dev);
 	property_box_changed();
+	g_free(dev);
+}
+
+static int get_dev_index(const char **devnames, const char *dev){
+	int i;
+	for (i=0;devnames[i]!=NULL;i++){
+		if (strcmp(devnames[i],dev)==0)
+			return i;
+	}
+	g_warning("could not find %s in device list.",dev);
+	return 0;
 }
 
 void sound_section_fill(SoundSection *sec, LinphoneCore *lc)
 {
-	SndCardManager *cardmanager;
-	SndCard *card;
 	GtkComboBox *play_card=GTK_COMBO_BOX(lookup_widget(get_property_box()->prop,"play_card"));
 	GtkComboBox *capt_card=GTK_COMBO_BOX(lookup_widget(get_property_box()->prop,"capt_card"));
 	GtkComboBox *ring_card=GTK_COMBO_BOX(lookup_widget(get_property_box()->prop,"ring_card"));
 	int i;
+	const char **devnames=linphone_core_get_sound_devices(lc);
 	/* select used sound drivers*/
-
-	cardmanager=linphone_core_get_card_manager(lc);
 	
-	for (i=0;(card=snd_card_manager_get_card(cardmanager,i))!=0;i++){
-		const gchar *carddesc=snd_card_get_identifier(card);
+	for (i=0;devnames[i]!=NULL;i++){
+		const char *carddesc=devnames[i];
 		gtk_combo_box_append_text(play_card,carddesc);
 		gtk_combo_box_append_text(capt_card,carddesc);
 		gtk_combo_box_append_text(ring_card,carddesc);
 	}
 	/*select used cards */
-	gtk_combo_box_set_active(play_card,linphone_core_get_playback_device(lc));
-	gtk_combo_box_set_active(capt_card,linphone_core_get_capture_device(lc));
-	gtk_combo_box_set_active(ring_card,linphone_core_get_ringer_device(lc));
+	gtk_combo_box_set_active(play_card,get_dev_index(devnames,linphone_core_get_playback_device(lc)));
+	gtk_combo_box_set_active(capt_card,get_dev_index(devnames,linphone_core_get_capture_device(lc)));
+	gtk_combo_box_set_active(ring_card,get_dev_index(devnames,linphone_core_get_ringer_device(lc)));
 	/* select audio source*/
 	switch(linphone_core_get_sound_source(lc))
 	{
@@ -681,12 +613,13 @@ void sound_section_fill(SoundSection *sec, LinphoneCore *lc)
   			break;
 		default:
 			g_warning("Invalid source !");
-  }
-  {
-		gchar *ringfile=linphone_core_get_ring(lc);
-		gnome_file_entry_set_filename(GNOME_FILE_ENTRY(sec->ringfileentry),ringfile);
-		
-  }
+	}
+	{
+			gchar *ringfile=linphone_core_get_ring(lc);
+			gnome_file_entry_set_filename(GNOME_FILE_ENTRY(sec->ringfileentry),ringfile);
+			
+	}
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lookup_widget(get_property_box()->prop,"echocancelation")),linphone_core_echo_cancelation_enabled(lc));
 }
 
 
@@ -711,10 +644,10 @@ void sound_section_apply(SoundSection *sec, LinphoneCore *lc)
 
 void ring_finished(LinphoneCore *lc,gpointer user_data)
 {
-  GtkWidget *button=(GtkWidget*)user_data;
-  LinphonePropertyBox *prop=get_property_box();
-  if (prop->prop==NULL) return; /* the box has been closed before the end of the preview */
-  gtk_widget_set_sensitive(button,1);
+	GtkWidget *button=(GtkWidget*)user_data;
+	LinphonePropertyBox *prop=get_property_box();
+	if (prop->prop==NULL) return; /* the box has been closed before the end of the preview */
+	gtk_widget_set_sensitive(button,1);
 }
 
 void
@@ -737,7 +670,7 @@ void linphone_property_box_fill(LinphonePropertyBox * box, LinphoneCore *lp)
 {
 	net_section_fill(&box->net,lp);
 	sip_section_fill(&box->sip,lp);
-	codec_section_fill(&box->codec,lp);
+	codec_section_fill(&box->codec,lp,box->prop);
 	sound_section_fill(&box->sound,lp);
 	/* set uchanged state to the prop1 box, because gtk_entry_set_text() causes signal "changed"
   	to be sent */
@@ -825,8 +758,8 @@ void codec_row_move(GtkTreeView *listview, int action)
 	GtkTreePath *treepath;
     struct _PayloadType *codec=NULL;
 	gchar *name=NULL;
-	gchar *rate=NULL;
-	gchar *bitrate=NULL;
+	gint rate;
+	gfloat bitrate;
 	gchar *status=NULL;
 	gchar *color=NULL;
 	
@@ -875,8 +808,6 @@ void codec_row_move(GtkTreeView *listview, int action)
 		gtk_list_store_remove(GTK_LIST_STORE(model),&iter);
 		gtk_tree_selection_select_iter(selection,&newiter);
 		g_free(name);
-		g_free(bitrate);
-		g_free(rate);
 		g_free(status);
 		g_free(color);
 	}
@@ -918,22 +849,23 @@ void codec_set_status(GtkTreeView *listview,gboolean status)
 	}
 }
 
-void codec_list_update(GtkTreeView *listview,double bandwidth)
+void codec_list_update(GtkTreeView *listview)
 {
 	GtkTreeModel *model;
 	GtkTreeIter iter;
-	struct _PayloadType *pt;
+	PayloadType *pt;
 	gchar *color;
+	gfloat bitrate;
 	model=gtk_tree_view_get_model(listview);
 	
 	g_return_if_fail(gtk_tree_model_get_iter_first(model,&iter));
 	do{
 		gtk_tree_model_get (model, &iter, 	CODEC_PRIVDATA, &pt,-1);
-		if (payload_type_usable(pt)){
+		if (linphone_core_check_payload_type_usability(get_core(),pt)){
 			color="blue";
 		}else color="red";
-		gtk_list_store_set(GTK_LIST_STORE(model),&iter,CODEC_COLOR,color,-1);
-		
+		bitrate=payload_type_get_bitrate(pt)/1000.0;
+		gtk_list_store_set(GTK_LIST_STORE(model),&iter,CODEC_COLOR,color,CODEC_BITRATE,bitrate,-1);
 	}while (gtk_tree_model_iter_next(model,&iter));
 }
 
@@ -1046,3 +978,54 @@ on_guess_hostname_toggled              (GtkToggleButton *togglebutton,
 	gtk_widget_set_sensitive(hostname,!val);
 	osip_from_free(from);
 }
+
+void
+on_download_bw_value_changed           (GtkSpinButton   *spinbutton,
+                                        gpointer         user_data)
+{
+	gdouble val=gtk_spin_button_get_value(spinbutton);
+	if (val==0) gtk_entry_set_text(GTK_ENTRY(spinbutton),_("Unlimited"));
+	linphone_core_set_download_bandwidth(get_core(),(int)val);
+	codec_list_update(GTK_TREE_VIEW(lookup_widget(gtk_widget_get_toplevel(GTK_WIDGET(spinbutton)),"au_codec_list")));
+}
+
+void
+on_upload_bw_value_changed             (GtkSpinButton   *spinbutton,
+                                        gpointer         user_data)
+{
+	gdouble val=gtk_spin_button_get_value(spinbutton);
+	if (val==0) gtk_entry_set_text(GTK_ENTRY(spinbutton),_("Unlimited"));
+	linphone_core_set_upload_bandwidth(get_core(),(int)val);
+	codec_list_update(GTK_TREE_VIEW(lookup_widget(gtk_widget_get_toplevel(GTK_WIDGET(spinbutton)),"au_codec_list")));
+}
+
+void
+on_no_nat_toggled                      (GtkToggleButton *togglebutton,
+                                        gpointer         user_data)
+{
+	property_box_changed();
+}
+
+
+void
+on_use_stun_toggled                    (GtkToggleButton *togglebutton,
+                                        gpointer         user_data)
+{
+	property_box_changed();
+}
+
+
+void
+on_static_nat_toggled                  (GtkToggleButton *togglebutton,
+                                        gpointer         user_data)
+{
+	property_box_changed();
+}
+
+void
+on_stun_server_changed                 (GtkEditable     *editable,
+                                        gpointer         user_data)
+{
+	property_box_changed();
+}
+
