@@ -60,8 +60,6 @@ struct _CodecSection
 {
 	GtkWidget *au_codec_list;
 	GtkWidget *codec_info;
-	GtkWidget *connection_type;
-	gint type_sel;
 };
 
 typedef struct _CodecSection CodecSection;
