@@ -1,5 +1,5 @@
 /*
-  The oRTP library is an RTP (Realtime Transport Protocol - rfc1889) stack.
+  The oRTP library is an RTP (Realtime Transport Protocol - rfc3550) stack.
   Copyright (C) 2001  Simon MORLAT simon.morlat@linphone.org
 
   This library is free software; you can redistribute it and/or
@@ -28,10 +28,11 @@
 extern "C"
 {
 #endif
+
 bool_t ortp_min_version_required(int major, int minor, int micro);
-void ortp_init();
-void ortp_scheduler_init();
-void ortp_exit();
+void ortp_init(void);
+void ortp_scheduler_init(void);
+void ortp_exit(void);
 
 /***************/
 /* logging api */
@@ -52,18 +53,22 @@ typedef void (*OrtpLogFunc)(OrtpLogLevel lev, const char *fmt, va_list args);
 void ortp_set_log_file(FILE *file);
 void ortp_set_log_handler(OrtpLogFunc func);
 
-extern OrtpLogFunc ortp_logv_out;
+VAR_DECLSPEC OrtpLogFunc ortp_logv_out;
 
 extern unsigned int __ortp_log_mask;
 
 #define ortp_log_level_enabled(level)	(__ortp_log_mask & (level))
 
+#ifndef WIN32
 #define ortp_logv(level,fmt,args) \
 {\
 	if (ortp_logv_out!=NULL && ortp_log_level_enabled(level)) \
 		ortp_logv_out(level,fmt,args);\
 	if ((level)==ORTP_FATAL) abort();\
 }while(0)
+#else
+void ortp_logv(int level, const char *fmt, va_list args);
+#endif
 
 void ortp_set_log_level_mask(int levelmask);
 
@@ -83,8 +88,17 @@ static inline void ortp_debug(const char *fmt,...)
   va_end (args);
 }
 #else
+#ifdef WIN32
+static inline void ortp_debug(const char *fmt,...)
+{
+  va_list args;
+  va_start (args, fmt);
+  va_end (args);
+}
+#else
 #define ortp_debug(...)
 #endif
+#endif
 
 static inline void ortp_message(const char *fmt,...)
 {
@@ -125,11 +139,11 @@ static inline void ortp_fatal(const char *fmt,...)
 
 extern rtp_stats_t ortp_global_stats;
 
-void ortp_global_stats_reset();
-rtp_stats_t *ortp_get_global_stats();
+void ortp_global_stats_reset(void);
+rtp_stats_t *ortp_get_global_stats(void);
 
-void ortp_global_stats_display();
-void rtp_stats_display(rtp_stats_t *stats, const char *header);
+void ortp_global_stats_display(void);
+void rtp_stats_display(const rtp_stats_t *stats, const char *header);
 void rtp_stats_reset(rtp_stats_t *stats);
 
 #ifdef __cplusplus
