@@ -34,13 +34,14 @@
 #define	PAYLOAD_TYPE_USER_FLAG_2 (1<<6)
 	/* ask for more if you need*/
 
+#define PAYLOAD_AUDIO_CONTINUOUS 0
+#define PAYLOAD_AUDIO_PACKETIZED 1
+#define PAYLOAD_VIDEO 2
+#define PAYLOAD_OTHER 3  /* ?? */
+
 struct _PayloadType
 {
 	int type;
-	#define PAYLOAD_AUDIO_CONTINUOUS 0
-	#define PAYLOAD_AUDIO_PACKETIZED 1
-	#define	PAYLOAD_VIDEO 2
-	#define PAYLOAD_OTHER 3  /* ?? */
 	int clock_rate;
 	char bits_per_sample;		/* in case of continuous audio data */
 	char *zero_pattern;
@@ -61,6 +62,7 @@ typedef struct _PayloadType PayloadType;
 
 #define payload_type_set_flag(pt,flag) (pt)->flags|=((int)flag)
 #define payload_type_unset_flag(pt,flag) (pt)->flags&=(~(int)flag)
+#define payload_type_get_flags(pt)	(pt)->flags
 
 #define RTP_PROFILE_MAX_PAYLOADS 128
 
@@ -76,13 +78,17 @@ typedef struct _RtpProfile RtpProfile;
 #ifdef __cplusplus
 extern "C"{
 #endif
-PayloadType *payload_type_new();
+PayloadType *payload_type_new(void);
 PayloadType *payload_type_clone(PayloadType *payload);
 void payload_type_destroy(PayloadType *pt);
 void payload_type_set_recv_fmtp(PayloadType *pt, const char *fmtp);
 void payload_type_set_send_fmtp(PayloadType *pt, const char *fmtp);
 
-extern RtpProfile av_profile;
+/*parses a fmtp string such as "profile=0;level=10", finds the value matching parameter
+param_name, and writes it into result. Returns TRUE if the parameter was found. */
+bool_t fmtp_get_value(const char *fmtp, const char *param_name, char *result, size_t result_len);
+
+VAR_DECLSPEC RtpProfile av_profile;
 
 #ifdef __cplusplus
 }
@@ -100,16 +106,16 @@ extern RtpProfile av_profile;
 extern "C"{
 #endif
 
-void rtp_profile_set_payload(RtpProfile *prof, int index, PayloadType *pt);
+void rtp_profile_set_payload(RtpProfile *prof, int idx, PayloadType *pt);
 
 #define rtp_profile_clear_payload(profile,index)	rtp_profile_set_payload(profile,index,NULL)	
 
 /* I prefer have this function inlined because it is very often called in the code */
-static inline PayloadType * rtp_profile_get_payload(RtpProfile *prof, int index){
-	if (index<0 || index>=RTP_PROFILE_MAX_PAYLOADS) {
+static inline PayloadType * rtp_profile_get_payload(RtpProfile *prof, int idx){
+	if (idx<0 || idx>=RTP_PROFILE_MAX_PAYLOADS) {
 		return NULL;
 	}
-	return prof->payload[index];
+	return prof->payload[idx];
 }
 void rtp_profile_clear_all(RtpProfile *prof);
 void rtp_profile_set_name(RtpProfile *prof, const char *name);
@@ -136,28 +142,32 @@ void rtp_profile_destroy(RtpProfile *prof);
 
 /* some payload types */
 /* audio */
-extern PayloadType payload_type_pcmu8000;
-extern PayloadType payload_type_pcma8000;
-extern PayloadType payload_type_pcm8000;
-extern PayloadType payload_type_lpc1016;
-extern PayloadType payload_type_gsm;
-extern PayloadType payload_type_lpc1015;
-extern PayloadType payload_type_speex_nb;
-extern PayloadType payload_type_speex_wb;
-extern PayloadType payload_type_ilbc;
-extern PayloadType payload_type_amr;
-extern PayloadType payload_type_amrwb;
-extern PayloadType payload_type_truespeech;
+VAR_DECLSPEC PayloadType payload_type_pcmu8000;
+VAR_DECLSPEC PayloadType payload_type_pcma8000;
+VAR_DECLSPEC PayloadType payload_type_pcm8000;
+VAR_DECLSPEC PayloadType payload_type_lpc1016;
+VAR_DECLSPEC PayloadType payload_type_g729;
+VAR_DECLSPEC PayloadType payload_type_g7231;
+VAR_DECLSPEC PayloadType payload_type_gsm;
+VAR_DECLSPEC PayloadType payload_type_lpc1015;
+VAR_DECLSPEC PayloadType payload_type_speex_nb;
+VAR_DECLSPEC PayloadType payload_type_speex_wb;
+VAR_DECLSPEC PayloadType payload_type_ilbc;
+VAR_DECLSPEC PayloadType payload_type_amr;
+VAR_DECLSPEC PayloadType payload_type_amrwb;
+VAR_DECLSPEC PayloadType payload_type_truespeech;
 
 /* video */
-extern PayloadType payload_type_mpv;
-extern PayloadType payload_type_h261;
-extern PayloadType payload_type_h263;
-extern PayloadType payload_type_h263_1998;
-extern PayloadType payload_type_h263_2000;
-extern PayloadType payload_type_mp4v;
-
+VAR_DECLSPEC PayloadType payload_type_mpv;
+VAR_DECLSPEC PayloadType payload_type_h261;
+VAR_DECLSPEC PayloadType payload_type_h263;
+VAR_DECLSPEC PayloadType payload_type_h263_1998;
+VAR_DECLSPEC PayloadType payload_type_h263_2000;
+VAR_DECLSPEC PayloadType payload_type_mp4v;
+VAR_DECLSPEC PayloadType payload_type_theora;
 
+/* telephone-event */
+VAR_DECLSPEC PayloadType payload_type_telephone_event;
 
 
 #endif
