@@ -1,5 +1,5 @@
 /*
-  The oRTP library is an RTP (Realtime Transport Protocol - rfc1889) stack.
+  The oRTP library is an RTP (Realtime Transport Protocol - rfc3550) stack.
   Copyright (C) 2001  Simon MORLAT simon.morlat@linphone.org
 
   This library is free software; you can redistribute it and/or
@@ -89,7 +89,7 @@ struct _SessionSet
 
 typedef struct _SessionSet SessionSet;
 
-SessionSet * session_set_new();
+SessionSet * session_set_new(void);
 #define session_set_init(ss)		ORTP_FD_ZERO(&(ss)->rtpset)
 #define session_set_set(ss,rtpsession)		ORTP_FD_SET((rtpsession)->mask_pos,&(ss)->rtpset)
 #define session_set_is_set(ss,rtpsession)	ORTP_FD_ISSET((rtpsession)->mask_pos,&(ss)->rtpset)
